@@ -14,14 +14,12 @@ Archive Get Command
 #include "command/archive/get/protocol.h"
 #include "command/command.h"
 #include "common/debug.h"
-#include "common/fork.h"
 #include "common/log.h"
 #include "common/memContext.h"
 #include "common/regExp.h"
 #include "common/wait.h"
 #include "config/config.h"
 #include "config/exec.h"
-#include "perl/exec.h"
 #include "postgres/interface.h"
 #include "protocol/helper.h"
 #include "protocol/parallel.h"
@@ -101,14 +99,15 @@ queueNeed(const String *walSegment, bool found, uint64_t queueSize, size_t walSe
     FUNCTION_LOG_RETURN(STRING_LIST, result);
 }
 
-/***********************************************************************************************************************************
-Get an archive file from the repository (WAL segment, history file, etc.)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 cmdArchiveGet(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
 
+    // PostgreSQL must be local
+    pgIsLocalVerify();
+
     // Set the result assuming the archive file will not be found
     int result = 1;
 
@@ -141,7 +140,7 @@ cmdArchiveGet(void)
             bool found = false;                                         // Has the WAL segment been found yet?
             bool queueFull = false;                                     // Is the queue half or more full?
             bool forked = false;                                        // Has the async process been forked yet?
-            bool confessOnError = false;                                // Should we confess errors?
+            bool throwOnError = false;                                  // Should we throw errors?
 
             // Loop and wait for the WAL segment to be pushed
             Wait *wait = waitNew((TimeMSec)(cfgOptionDbl(cfgOptArchiveTimeout) * MSEC_PER_SEC));
@@ -150,7 +149,7 @@ cmdArchiveGet(void)
             {
                 // Check for errors or missing files.  For archive-get ok indicates that the process succeeded but there is no WAL
                 // file to download.
-                if (archiveAsyncStatus(archiveModeGet, walSegment, confessOnError))
+                if (archiveAsyncStatus(archiveModeGet, walSegment, throwOnError))
                 {
                     storageRemoveP(
                         storageSpoolWrite(),
@@ -218,7 +217,7 @@ cmdArchiveGet(void)
                     kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_STDERR_STR), VARSTRDEF("off"));
 
                     // Generate command options
-                    StringList *commandExec = cfgExecParam(cfgCmdArchiveGetAsync, optionReplace, true);
+                    StringList *commandExec = cfgExecParam(cfgCmdArchiveGet, cfgCmdRoleAsync, optionReplace, true, false);
                     strLstInsert(commandExec, 0, cfgExe());
 
                     // Clean the current queue using the list of WAL that we ideally want in the queue.  queueNeed()
@@ -230,23 +229,14 @@ cmdArchiveGet(void)
                     for (unsigned int queueIdx = 0; queueIdx < strLstSize(queue); queueIdx++)
                         strLstAdd(commandExec, strLstGet(queue, queueIdx));
 
+                    // Clear errors for the current wal segment
+                    archiveAsyncErrorClear(archiveModeGet, walSegment);
+
                     // Release the lock so the child process can acquire it
                     lockRelease(true);
 
-                    // Fork off the async process
-                    if (forkSafe() == 0)
-                    {
-                        // Disable logging and close log file
-                        logClose();
-
-                        // Detach from parent process
-                        forkDetach();
-
-                        // Execute the binary.  This statement will not return if it is successful.
-                        THROW_ON_SYS_ERROR(
-                            execvp(strPtr(cfgExe()), (char ** const)strLstPtr(commandExec)) == -1,
-                            ExecuteError, "unable to execute '" CFGCMD_ARCHIVE_GET_ASYNC "'");
-                    }
+                    // Execute the async process
+                    archiveAsyncExec(archiveModeGet, commandExec);
 
                     // Mark the async process as forked so it doesn't get forked again.  A single run of the async process should be
                     // enough to do the job, running it again won't help anything.
@@ -257,8 +247,8 @@ cmdArchiveGet(void)
                 if (found)
                     break;
 
-                // Now that the async process has been launched, confess any errors that are found
-                confessOnError = true;
+                // Now that the async process has been launched, throw any errors that are found
+                throwOnError = true;
             }
             while (waitMore(wait));
         }
@@ -285,9 +275,7 @@ cmdArchiveGet(void)
     FUNCTION_LOG_RETURN(INT, result);
 }
 
-/***********************************************************************************************************************************
-Async version of archive get that runs in parallel for performance
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 typedef struct ArchiveGetAsyncData
 {
     const StringList *walSegmentList;                               // List of wal segments to process
@@ -326,6 +314,9 @@ cmdArchiveGetAsync(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
 
+    // PostgreSQL must be local
+    pgIsLocalVerify();
+
     MEM_CONTEXT_TEMP_BEGIN()
     {
         TRY_BEGIN()
