@@ -1483,6 +1483,7 @@ static ProtocolParallelJob *backupJobCallback(void *data, unsigned int clientIdx
                 protocolCommandParamAdd(
                     command, VARBOOL(!strEq(file->name, STRDEF(MANIFEST_TARGET_PGDATA "/" PG_PATH_GLOBAL "/" PG_FILE_PGCONTROL))));
                 protocolCommandParamAdd(command, VARUINT64(file->size));
+                protocolCommandParamAdd(command, VARBOOL(!file->primary));
                 protocolCommandParamAdd(command, file->checksumSha1[0] != 0 ? VARSTRZ(file->checksumSha1) : NULL);
                 protocolCommandParamAdd(command, VARBOOL(file->checksumPage));
                 protocolCommandParamAdd(command, VARUINT64(jobData->lsnStart));
@@ -1929,9 +1930,7 @@ backupComplete(InfoBackup *const infoBackup, Manifest *const manifest)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Make a backup
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 cmdBackup(void)
 {
