@@ -634,9 +634,7 @@ removeExpiredBackup(InfoBackup *infoBackup)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Expire backups and archives
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 cmdExpire(void)
 {
