@@ -22,7 +22,6 @@ Info Command
 #include "info/infoBackup.h"
 #include "info/infoPg.h"
 #include "info/manifest.h"
-#include "perl/exec.h"
 #include "postgres/interface.h"
 #include "storage/helper.h"
 
@@ -803,18 +802,18 @@ infoRender(void)
         else
             resultStr = jsonFromVar(varNewVarLst(infoList));
 
-        memContextSwitch(MEM_CONTEXT_OLD());
-        result = strDup(resultStr);
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result = strDup(resultStr);
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(STRING, result);
 }
 
-/***********************************************************************************************************************************
-Render info and output to stdout
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 cmdInfo(void)
 {
