@@ -61,28 +61,55 @@ typedef struct ErrorType ErrorType;
 /***********************************************************************************************************************************
 Functions to get information about a generic error type
 ***********************************************************************************************************************************/
+// Error type code
 int errorTypeCode(const ErrorType *errorType);
+
+// Get error type using a code
 const ErrorType *errorTypeFromCode(int code);
+
+// Error type name
 const char *errorTypeName(const ErrorType *errorType);
+
+// Error type parent
 const ErrorType *errorTypeParent(const ErrorType *errorType);
+
+// Does the child error type extend the parent error type?
 bool errorTypeExtends(const ErrorType *child, const ErrorType *parent);
 
 /***********************************************************************************************************************************
 Functions to get information about the current error
 ***********************************************************************************************************************************/
+// Error type
 const ErrorType *errorType(void);
+
+// Error code (pulled from error type)
 int errorCode(void);
+
+// Error filename
 const char *errorFileName(void);
+
+// Error function name
 const char *errorFunctionName(void);
+
+// Error file line number
 int errorFileLine(void);
+
+// Is this error an instance of the error type?
 bool errorInstanceOf(const ErrorType *errorTypeTest);
+
+// Error message
 const char *errorMessage(void);
+
+// Error name (pulled from error type)
 const char *errorName(void);
+
+// Error stack trace
 const char *errorStackTrace(void);
 
 /***********************************************************************************************************************************
 Functions to get information about the try stack
 ***********************************************************************************************************************************/
+// Get the depth of the current try statement (0 if none)
 unsigned int errorTryDepth(void);
 
 /***********************************************************************************************************************************
@@ -148,70 +175,14 @@ The seldom used "THROWP" variants allow an error to be thrown with a pointer to
 /***********************************************************************************************************************************
 Throw an error when a system call fails
 ***********************************************************************************************************************************/
-// When coverage testing define special versions of the macros that don't contain branches.  These macros are less efficient because
-// they need to call errorInternalThrowSys*() before determining if there is an error or not, but they allow coverage testing for
-// THROW*_ON*() calls that contain conditionals.
-#ifdef DEBUG_COVERAGE
-    #define THROW_SYS_ERROR(errorType, message)                                                                                    \
-        errorInternalThrowSys(true, &errorType, __FILE__, __func__, __LINE__, message)
-    #define THROW_SYS_ERROR_FMT(errorType, ...)                                                                                    \
-        errorInternalThrowSysFmt(true, &errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
-    #define THROWP_SYS_ERROR(errorType, message)                                                                                   \
-        errorInternalThrowSys(true, errorType, __FILE__, __func__, __LINE__, message)
-    #define THROWP_SYS_ERROR_FMT(errorType, ...)                                                                                   \
-        errorInternalThrowSysFmt(true, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
-
-    #define THROW_ON_SYS_ERROR(error, errorType, message)                                                                          \
-        errorInternalThrowSys(error, &errorType, __FILE__, __func__, __LINE__, message)
-
-    #define THROW_ON_SYS_ERROR_FMT(error, errorType, ...)                                                                          \
-        errorInternalThrowSysFmt(error, &errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
-
-    #define THROWP_ON_SYS_ERROR(error, errorType, message)                                                                         \
-        errorInternalThrowSys(error, errorType, __FILE__, __func__, __LINE__, message)
-
-    #define THROWP_ON_SYS_ERROR_FMT(error, errorType, ...)                                                                         \
-        errorInternalThrowSysFmt(error, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
-
-// Else define the normal macros which check for an error first
-#else
-    #define THROW_SYS_ERROR(errorType, message)                                                                                    \
-        errorInternalThrowSys(errno, &errorType, __FILE__, __func__, __LINE__, message)
-    #define THROW_SYS_ERROR_FMT(errorType, ...)                                                                                    \
-        errorInternalThrowSysFmt(errno, &errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
-    #define THROWP_SYS_ERROR(errorType, message)                                                                                   \
-        errorInternalThrowSys(errno, errorType, __FILE__, __func__, __LINE__, message)
-    #define THROWP_SYS_ERROR_FMT(errorType, ...)                                                                                   \
-        errorInternalThrowSysFmt(errno, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
-
-    #define THROW_ON_SYS_ERROR(error, errorType, message)                                                                          \
-        do                                                                                                                         \
-        {                                                                                                                          \
-            if (error)                                                                                                             \
-                errorInternalThrowSys(errno, &errorType, __FILE__, __func__, __LINE__, message);                                   \
-        } while(0)
-
-    #define THROW_ON_SYS_ERROR_FMT(error, errorType, ...)                                                                          \
-        do                                                                                                                         \
-        {                                                                                                                          \
-            if (error)                                                                                                             \
-                errorInternalThrowSysFmt(errno, &errorType, __FILE__, __func__, __LINE__, __VA_ARGS__);                            \
-        } while(0)
-
-    #define THROWP_ON_SYS_ERROR(error, errorType, message)                                                                         \
-        do                                                                                                                         \
-        {                                                                                                                          \
-            if (error)                                                                                                             \
-                errorInternalThrowSys(errno, errorType, __FILE__, __func__, __LINE__, message);                                    \
-        } while(0)
-
-    #define THROWP_ON_SYS_ERROR_FMT(error, errorType, ...)                                                                         \
-        do                                                                                                                         \
-        {                                                                                                                          \
-            if (error)                                                                                                             \
-                errorInternalThrowSysFmt(errno, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__);                             \
-        } while(0)
-#endif
+#define THROW_SYS_ERROR(errorType, message)                                                                                        \
+    errorInternalThrowSys(errno, &errorType, __FILE__, __func__, __LINE__, message)
+#define THROW_SYS_ERROR_FMT(errorType, ...)                                                                                        \
+    errorInternalThrowSysFmt(errno, &errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
+#define THROWP_SYS_ERROR(errorType, message)                                                                                       \
+    errorInternalThrowSys(errno, errorType, __FILE__, __func__, __LINE__, message)
+#define THROWP_SYS_ERROR_FMT(errorType, ...)                                                                                       \
+    errorInternalThrowSysFmt(errno, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
 
 #define THROW_SYS_ERROR_CODE(errNo, errorType, message)                                                                            \
     errorInternalThrowSys(errNo, &errorType, __FILE__, __func__, __LINE__, message)
@@ -222,6 +193,72 @@ Throw an error when a system call fails
 #define THROWP_SYS_ERROR_CODE_FMT(errNo, errorType, ...)                                                                           \
     errorInternalThrowSysFmt(errNo, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__)
 
+// When coverage testing, define special versions of the macros that don't contain branches. These macros are less efficient because
+// they need to call errorInternalThrowOnSys*() before determining if there is an error or not, but they allow coverage testing for
+// THROW*_ON*() calls that contain conditionals.
+#ifdef DEBUG_COVERAGE
+
+    // The expression can't be passed directly to errorInternalThrowSys*() because we need to be sure it is evaluated before passing
+    // errno. Depending on optimization that might not happen.
+    #define THROW_ON_SYS_ERROR(expression, errorType, message)                                                                     \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            bool error = expression;                                                                                               \
+            errorInternalThrowOnSys(error, errno, &errorType, __FILE__, __func__, __LINE__, message);                              \
+        } while(0)
+
+    #define THROW_ON_SYS_ERROR_FMT(expression, errorType, ...)                                                                     \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            bool error = expression;                                                                                               \
+            errorInternalThrowOnSysFmt(error, errno, &errorType, __FILE__, __func__, __LINE__, __VA_ARGS__);                       \
+        } while(0)
+
+    #define THROWP_ON_SYS_ERROR(expression, errorType, message)                                                                    \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            bool error = expression;                                                                                               \
+            errorInternalThrowOnSys(error, errno, errorType, __FILE__, __func__, __LINE__, message);                               \
+        } while(0)
+
+    #define THROWP_ON_SYS_ERROR_FMT(expression, errorType, ...)                                                                    \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            bool error = expression;                                                                                               \
+            errorInternalThrowOnSysFmt(error, errno, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__);                        \
+        } while(0)
+
+// Else define the normal macros which check for an error first
+#else
+    #define THROW_ON_SYS_ERROR(expression, errorType, message)                                                                     \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            if (expression)                                                                                                        \
+                errorInternalThrowSys(errno, &errorType, __FILE__, __func__, __LINE__, message);                                   \
+        } while(0)
+
+    #define THROW_ON_SYS_ERROR_FMT(expression, errorType, ...)                                                                     \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            if (expression)                                                                                                        \
+                errorInternalThrowSysFmt(errno, &errorType, __FILE__, __func__, __LINE__, __VA_ARGS__);                            \
+        } while(0)
+
+    #define THROWP_ON_SYS_ERROR(expression, errorType, message)                                                                    \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            if (expression)                                                                                                        \
+                errorInternalThrowSys(errno, errorType, __FILE__, __func__, __LINE__, message);                                    \
+        } while(0)
+
+    #define THROWP_ON_SYS_ERROR_FMT(expression, errorType, ...)                                                                    \
+        do                                                                                                                         \
+        {                                                                                                                          \
+            if (expression)                                                                                                        \
+                errorInternalThrowSysFmt(errno, errorType, __FILE__, __func__, __LINE__, __VA_ARGS__);                             \
+        } while(0)
+#endif
+
 /***********************************************************************************************************************************
 Rethrow the current error
 ***********************************************************************************************************************************/
@@ -233,13 +270,28 @@ Internal functions
 
 These functions are used by the macros to implement the error handler and should never be called independently.
 ***********************************************************************************************************************************/
+// Begin the try block
 bool errorInternalTry(const char *fileName, const char *functionName, int fileLine);
+
+// Return jump buffer for current try
 jmp_buf *errorInternalJump(void);
+
+// True when in try state
 bool errorInternalStateTry(void);
+
+// True when in catch state and the expected error matches
 bool errorInternalStateCatch(const ErrorType *errorTypeCatch);
+
+// True when in final state
 bool errorInternalStateFinal(void);
+
+// Process the error through each try and state
 bool errorInternalProcess(bool catch);
+
+// Propagate the error up so it can be caught
 void errorInternalPropagate(void) __attribute__((__noreturn__));
+
+// Throw an error
 void errorInternalThrow(
     const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
     __attribute__((__noreturn__));
@@ -247,31 +299,25 @@ void errorInternalThrowFmt(
     const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *format, ...)
     __attribute__((format(printf, 5, 6))) __attribute__((__noreturn__));
 
+// Throw a system error
 void errorInternalThrowSys(
-#ifdef DEBUG_COVERAGE
-    bool error,
-#else
-    int errNo,
-#endif
-    const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
-#ifdef DEBUG_COVERAGE
-    ;
-#else
+    int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *message)
     __attribute__((__noreturn__));
-#endif
 
+// Throw a formatted system error
 void errorInternalThrowSysFmt(
+    int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *format, ...)
+    __attribute__((format(printf, 6, 7))) __attribute__((__noreturn__));
+
+// Versions of the above for coverage testing which checks the error condition inside the function
 #ifdef DEBUG_COVERAGE
-    bool error,
-#else
-    int errNo,
-#endif
-    const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine, const char *format, ...)
-    __attribute__((format(printf, 6, 7)))
-#ifdef DEBUG_COVERAGE
-    ;
-#else
-    __attribute__((__noreturn__));
+    void errorInternalThrowOnSys(
+        bool error, int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine,
+        const char *message);
+
+    void errorInternalThrowOnSysFmt(
+        bool error, int errNo, const ErrorType *errorType, const char *fileName, const char *functionName, int fileLine,
+        const char *format, ...) __attribute__((format(printf, 7, 8)));
 #endif
 
 /***********************************************************************************************************************************
