@@ -10,7 +10,7 @@ Http Client
 #include "common/io/read.intern.h"
 #include "common/io/tls/client.h"
 #include "common/log.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "common/wait.h"
 
 /***********************************************************************************************************************************
@@ -32,6 +32,7 @@ STRING_EXTERN(HTTP_HEADER_CONTENT_MD5_STR,                          HTTP_HEADER_
 #define HTTP_HEADER_TRANSFER_ENCODING                               "transfer-encoding"
     STRING_STATIC(HTTP_HEADER_TRANSFER_ENCODING_STR,                HTTP_HEADER_TRANSFER_ENCODING);
 STRING_EXTERN(HTTP_HEADER_ETAG_STR,                                 HTTP_HEADER_ETAG);
+STRING_EXTERN(HTTP_HEADER_LAST_MODIFIED_STR,                        HTTP_HEADER_LAST_MODIFIED);
 
 #define HTTP_VALUE_CONNECTION_CLOSE                                 "close"
     STRING_STATIC(HTTP_VALUE_CONNECTION_CLOSE_STR,                  HTTP_VALUE_CONNECTION_CLOSE);
@@ -54,7 +55,8 @@ struct HttpClient
     MemContext *memContext;                                         // Mem context
     TimeMSec timeout;                                               // Request timeout
 
-    TlsClient *tls;                                                 // Tls client
+    TlsClient *tlsClient;                                           // TLS client
+    TlsSession *tlsSession;                                         // Current TLS session
     IoRead *ioRead;                                                 // Read io interface
 
     unsigned int responseCode;                                      // Response code (e.g. 200, 404)
@@ -93,62 +95,76 @@ httpClientRead(THIS_VOID, Buffer *buffer, bool block)
 
     if (!this->contentEof)
     {
-        do
+        // If close was requested and no content specified then the server may send content up until the eof
+        if (this->closeOnContentEof && !this->contentChunked && this->contentSize == 0)
         {
-            // If chunked content and no content remaining
-            if (this->contentChunked && this->contentRemaining == 0)
+            ioRead(tlsSessionIoRead(this->tlsSession), buffer);
+            this->contentEof = ioReadEof(tlsSessionIoRead(this->tlsSession));
+        }
+        // Else read using specified encoding or size
+        else
+        {
+            do
             {
-                // Read length of next chunk
-                MEM_CONTEXT_TEMP_BEGIN()
+                // If chunked content and no content remaining
+                if (this->contentChunked && this->contentRemaining == 0)
                 {
-                    this->contentRemaining = cvtZToUInt64Base(strPtr(strTrim(ioReadLine(tlsClientIoRead(this->tls)))), 16);
+                    // Read length of next chunk
+                    MEM_CONTEXT_TEMP_BEGIN()
+                    {
+                        this->contentRemaining = cvtZToUInt64Base(
+                            strPtr(strTrim(ioReadLine(tlsSessionIoRead(this->tlsSession)))), 16);
+                    }
+                    MEM_CONTEXT_TEMP_END();
+
+                    // If content remaining is still zero then eof
+                    if (this->contentRemaining == 0)
+                        this->contentEof = true;
                 }
-                MEM_CONTEXT_TEMP_END();
 
-                // If content remaining is still zero then eof
-                if (this->contentRemaining == 0)
-                    this->contentEof = true;
-            }
-
-            // Read if there is content remaining
-            if (this->contentRemaining > 0)
-            {
-                // If the buffer is larger than the content that needs to be read then limit the buffer size so the read won't block
-                // or read too far.  Casting to size_t is safe on 32-bit because we know the max buffer size is defined as less than
-                // 2^32 so content remaining can't be more than that.
-                if (bufRemains(buffer) > this->contentRemaining)
-                    bufLimitSet(buffer, bufSize(buffer) - (bufRemains(buffer) - (size_t)this->contentRemaining));
+                // Read if there is content remaining
+                if (this->contentRemaining > 0)
+                {
+                    // If the buffer is larger than the content that needs to be read then limit the buffer size so the read won't
+                    // block or read too far.  Casting to size_t is safe on 32-bit because we know the max buffer size is defined as
+                    // less than 2^32 so content remaining can't be more than that.
+                    if (bufRemains(buffer) > this->contentRemaining)
+                        bufLimitSet(buffer, bufSize(buffer) - (bufRemains(buffer) - (size_t)this->contentRemaining));
 
-                actualBytes = bufRemains(buffer);
-                this->contentRemaining -= ioRead(tlsClientIoRead(this->tls), buffer);
+                    actualBytes = bufRemains(buffer);
+                    this->contentRemaining -= ioRead(tlsSessionIoRead(this->tlsSession), buffer);
 
-                // Error if EOF but content read is not complete
-                if (ioReadEof(tlsClientIoRead(this->tls)))
-                    THROW(FileReadError, "unexpected EOF reading HTTP content");
+                    // Error if EOF but content read is not complete
+                    if (ioReadEof(tlsSessionIoRead(this->tlsSession)))
+                        THROW(FileReadError, "unexpected EOF reading HTTP content");
 
-                // Clear limit (this works even if the limit was not set and it is easier than checking)
-                bufLimitClear(buffer);
-            }
+                    // Clear limit (this works even if the limit was not set and it is easier than checking)
+                    bufLimitClear(buffer);
+                }
 
-            // If no content remaining
-            if (this->contentRemaining == 0)
-            {
-                // If chunked then consume the blank line that follows every chunk.  There might be more chunk data so loop back
-                // around to check.
-                if (this->contentChunked)
+                // If no content remaining
+                if (this->contentRemaining == 0)
                 {
-                    ioReadLine(tlsClientIoRead(this->tls));
+                    // If chunked then consume the blank line that follows every chunk.  There might be more chunk data so loop back
+                    // around to check.
+                    if (this->contentChunked)
+                    {
+                        ioReadLine(tlsSessionIoRead(this->tlsSession));
+                    }
+                    // If total content size was provided then this is eof
+                    else
+                        this->contentEof = true;
                 }
-                // If total content size was provided then this is eof
-                else
-                    this->contentEof = true;
             }
+            while (!bufFull(buffer) && !this->contentEof);
         }
-        while (!bufFull(buffer) && !this->contentEof);
 
         // If the server notified that it would close the connection after sending content then close the client side
         if (this->contentEof && this->closeOnContentEof)
-            tlsClientClose(this->tls);
+        {
+            tlsSessionFree(this->tlsSession);
+            this->tlsSession = NULL;
+        }
     }
 
     FUNCTION_LOG_RETURN(SIZE, (size_t)actualBytes);
@@ -171,9 +187,7 @@ httpClientEof(THIS_VOID)
     FUNCTION_LOG_RETURN(BOOL, this->contentEof);
 }
 
-/***********************************************************************************************************************************
-New object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 HttpClient *
 httpClientNew(
     const String *host, unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath)
@@ -193,12 +207,14 @@ httpClientNew(
 
     MEM_CONTEXT_NEW_BEGIN("HttpClient")
     {
-        // Allocate state and set context
         this = memNew(sizeof(HttpClient));
-        this->memContext = MEM_CONTEXT_NEW();
 
-        this->timeout = timeout;
-        this->tls = tlsClientNew(host, port, timeout, verifyPeer, caFile, caPath);
+        *this = (HttpClient)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .timeout = timeout,
+            .tlsClient = tlsClientNew(sckClientNew(host, port, timeout), timeout, verifyPeer, caFile, caPath),
+        };
 
         httpClientStatLocal.object++;
     }
@@ -207,9 +223,7 @@ httpClientNew(
     FUNCTION_LOG_RETURN(HTTP_CLIENT, this);
 }
 
-/***********************************************************************************************************************************
-Perform a request
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Buffer *
 httpClientRequest(
     HttpClient *this, const String *verb, const String *uri, const HttpQuery *query, const HttpHeader *requestHeader,
@@ -236,7 +250,7 @@ httpClientRequest(
     {
         bool complete = false;
         bool retry;
-        Wait *wait = this->timeout > 0 ? waitNew(this->timeout) : NULL;
+        Wait *wait = waitNew(this->timeout);
 
         do
         {
@@ -261,14 +275,21 @@ httpClientRequest(
 
             TRY_BEGIN()
             {
-                if (tlsClientOpen(this->tls))
-                    httpClientStatLocal.session++;
+                if (this->tlsSession == NULL)
+                {
+                    MEM_CONTEXT_BEGIN(this->memContext)
+                    {
+                        this->tlsSession = tlsClientOpen(this->tlsClient);
+                        httpClientStatLocal.session++;
+                    }
+                    MEM_CONTEXT_END();
+                }
 
                 // Write the request
                 String *queryStr = httpQueryRender(query);
 
                 ioWriteStrLine(
-                    tlsClientIoWrite(this->tls),
+                    tlsSessionIoWrite(this->tlsSession),
                     strNewFmt(
                         "%s %s%s%s " HTTP_VERSION "\r", strPtr(verb), strPtr(httpUriEncode(uri, true)), queryStr == NULL ? "" : "?",
                         queryStr == NULL ? "" : strPtr(queryStr)));
@@ -282,23 +303,23 @@ httpClientRequest(
                     {
                         const String *headerKey = strLstGet(headerList, headerIdx);
                         ioWriteStrLine(
-                            tlsClientIoWrite(this->tls),
+                            tlsSessionIoWrite(this->tlsSession),
                             strNewFmt("%s:%s\r", strPtr(headerKey), strPtr(httpHeaderGet(requestHeader, headerKey))));
                     }
                 }
 
                 // Write out blank line to end the headers
-                ioWriteLine(tlsClientIoWrite(this->tls), CR_BUF);
+                ioWriteLine(tlsSessionIoWrite(this->tlsSession), CR_BUF);
 
                 // Write out body if any
                 if (body != NULL)
-                    ioWrite(tlsClientIoWrite(this->tls), body);
+                    ioWrite(tlsSessionIoWrite(this->tlsSession), body);
 
                 // Flush all writes
-                ioWriteFlush(tlsClientIoWrite(this->tls));
+                ioWriteFlush(tlsSessionIoWrite(this->tlsSession));
 
                 // Read status and make sure it starts with the correct http version
-                String *status = strTrim(ioReadLine(tlsClientIoRead(this->tls)));
+                String *status = strTrim(ioReadLine(tlsSessionIoRead(this->tlsSession)));
 
                 if (!strBeginsWith(status, HTTP_VERSION_STR))
                     THROW_FMT(FormatError, "http version of response '%s' must be " HTTP_VERSION, strPtr(status));
@@ -329,7 +350,7 @@ httpClientRequest(
                 do
                 {
                     // Read the next header
-                    String *header = strTrim(ioReadLine(tlsClientIoRead(this->tls)));
+                    String *header = strTrim(ioReadLine(tlsSessionIoRead(this->tlsSession)));
 
                     // If the header is empty then we have reached the end of the headers
                     if (strSize(header) == 0)
@@ -386,7 +407,8 @@ httpClientRequest(
                 }
 
                 // Was content returned in the response?  HEAD will report content but not actually return any.
-                bool contentExists = (this->contentChunked || this->contentSize > 0) && !strEq(verb, HTTP_VERB_HEAD_STR);
+                bool contentExists =
+                    (this->contentChunked || this->contentSize > 0 || this->closeOnContentEof) && !strEq(verb, HTTP_VERB_HEAD_STR);
                 this->contentEof = !contentExists;
 
                 // If all content should be returned from this function then read the buffer.  Also read the response if there has
@@ -419,7 +441,10 @@ httpClientRequest(
 
                 // If the server notified that it would close the connection and there is no content then close the client side
                 if (this->closeOnContentEof && !contentExists)
-                    tlsClientClose(this->tls);
+                {
+                    tlsSessionFree(this->tlsSession);
+                    this->tlsSession = NULL;
+                }
 
                 // Retry when response code is 5xx.  These errors generally represent a server error for a request that looks valid.
                 // There are a few errors that might be permanently fatal but they are rare and it seems best not to try and pick
@@ -433,7 +458,7 @@ httpClientRequest(
             CATCH_ANY()
             {
                 // Retry if wait time has not expired
-                if (wait != NULL && waitMore(wait))
+                if (waitMore(wait))
                 {
                     LOG_DEBUG_FMT("retry %s: %s", errorTypeName(errorType()), errorMessage());
                     retry = true;
@@ -441,7 +466,8 @@ httpClientRequest(
                     httpClientStatLocal.retry++;
                 }
 
-                tlsClientClose(this->tls);
+                tlsSessionFree(this->tlsSession);
+                this->tlsSession = NULL;
             }
             TRY_END();
         }
@@ -451,7 +477,7 @@ httpClientRequest(
             RETHROW();
 
         // Move the result buffer (if any) to the parent context
-        bufMove(result, MEM_CONTEXT_OLD());
+        bufMove(result, memContextPrior());
 
         httpClientStatLocal.request++;
     }
@@ -460,9 +486,7 @@ httpClientRequest(
     FUNCTION_LOG_RETURN(BUFFER, result);
 }
 
-/***********************************************************************************************************************************
-Format statistics to a string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 httpClientStatStr(void)
 {
@@ -482,9 +506,7 @@ httpClientStatStr(void)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Mark the client as done if read is complete
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 httpClientDone(HttpClient *this)
 {
@@ -496,8 +518,12 @@ httpClientDone(HttpClient *this)
 
     if (this->ioRead != NULL)
     {
+        // If it looks like we were in the middle of a response then close the TLS session so we can start clean next time
         if (!this->contentEof)
-            tlsClientClose(this->tls);
+        {
+            tlsSessionFree(this->tlsSession);
+            this->tlsSession = NULL;
+        }
 
         ioReadFree(this->ioRead);
         this->ioRead = NULL;
@@ -506,9 +532,7 @@ httpClientDone(HttpClient *this)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Is the http object busy?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 httpClientBusy(const HttpClient *this)
 {
@@ -521,9 +545,7 @@ httpClientBusy(const HttpClient *this)
     FUNCTION_TEST_RETURN(this->ioRead);
 }
 
-/***********************************************************************************************************************************
-Get read interface
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoRead *
 httpClientIoRead(const HttpClient *this)
 {
@@ -536,9 +558,7 @@ httpClientIoRead(const HttpClient *this)
     FUNCTION_TEST_RETURN(this->ioRead);
 }
 
-/***********************************************************************************************************************************
-Get the response code
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 httpClientResponseCode(const HttpClient *this)
 {
@@ -551,9 +571,7 @@ httpClientResponseCode(const HttpClient *this)
     FUNCTION_TEST_RETURN(this->responseCode);
 }
 
-/***********************************************************************************************************************************
-Is this response code OK, i.e. 2XX?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 httpClientResponseCodeOk(const HttpClient *this)
 {
@@ -566,9 +584,7 @@ httpClientResponseCodeOk(const HttpClient *this)
     FUNCTION_TEST_RETURN(this->responseCode / 100 == 2);
 }
 
-/***********************************************************************************************************************************
-Get the response headers
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const HttpHeader *
 httpClientResponseHeader(const HttpClient *this)
 {
@@ -581,9 +597,7 @@ httpClientResponseHeader(const HttpClient *this)
     FUNCTION_TEST_RETURN(this->responseHeader);
 }
 
-/***********************************************************************************************************************************
-Get the response message
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 httpClientResponseMessage(const HttpClient *this)
 {
