@@ -8,7 +8,7 @@ Regular Expression Handler
 
 #include "common/debug.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "common/regExp.h"
 
 /***********************************************************************************************************************************
@@ -53,9 +53,7 @@ regExpError(int error)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-New regular expression handler
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 RegExp *
 regExpNew(const String *expression)
 {
@@ -93,9 +91,7 @@ regExpNew(const String *expression)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Match on a regular expression
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 regExpMatch(RegExp *this, const String *string)
 {
@@ -131,7 +127,7 @@ regExpMatch(RegExp *this, const String *string)
 }
 
 /***********************************************************************************************************************************
-Getters
+Getters/Setters
 ***********************************************************************************************************************************/
 const char *
 regExpMatchPtr(RegExp *this)
@@ -169,9 +165,7 @@ regExpMatchStr(RegExp *this)
     FUNCTION_TEST_RETURN(this->matchPtr == NULL ? NULL : strNewN(regExpMatchPtr(this), regExpMatchSize(this)));
 }
 
-/***********************************************************************************************************************************
-Match a regular expression in one call for brevity
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 regExpMatchOne(const String *expression, const String *string)
 {
