@@ -59,9 +59,7 @@ struct String
     MemContext *memContext;                                         // Required for dynamically allocated strings
 };
 
-/***********************************************************************************************************************************
-Create a new string from a zero-terminated string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strNew(const char *string)
 {
@@ -94,12 +92,7 @@ strNew(const char *string)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Create a new string from a buffer
-
-If the buffer has a NULL character this may not work as expected.  All the data will be copied but only the data before the NULL
-character will be used as a string.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strNewBuf(const Buffer *buffer)
 {
@@ -123,15 +116,13 @@ strNewBuf(const Buffer *buffer)
 
     // Allocate and assign string
     this->buffer = memNew(this->size + 1);
-    memcpy(this->buffer, (char *)bufPtr(buffer), this->size);
+    memcpy(this->buffer, bufPtrConst(buffer), this->size);
     this->buffer[this->size] = 0;
 
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Create a new string from a format string with parameters (i.e. sprintf)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strNewFmt(const char *format, ...)
 {
@@ -168,11 +159,7 @@ strNewFmt(const char *format, ...)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Create a new string from a string with a specific length
-
-The string may or may not be zero-terminated but we'll use that nomenclature since we're not concerned about the end of the string.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strNewN(const char *string, size_t size)
 {
@@ -204,9 +191,7 @@ strNewN(const char *string, size_t size)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Return the file part of a string (i.e. everything after the last / or the entire string if there is no /)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strBase(const String *this)
 {
@@ -224,9 +209,7 @@ strBase(const String *this)
     FUNCTION_TEST_RETURN(strNew(end));
 }
 
-/***********************************************************************************************************************************
-Does the string begin with the specified string?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 strBeginsWith(const String *this, const String *beginsWith)
 {
@@ -294,9 +277,7 @@ strResize(String *this, size_t requested)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Append a string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strCat(String *this, const char *cat)
 {
@@ -348,9 +329,7 @@ strCatZN(String *this, const char *cat, size_t size)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Append a character
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strCatChr(String *this, char cat)
 {
@@ -373,9 +352,7 @@ strCatChr(String *this, char cat)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Append a formatted string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strCatFmt(String *this, const char *format, ...)
 {
@@ -407,9 +384,7 @@ strCatFmt(String *this, const char *format, ...)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-C-style string compare
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 strCmp(const String *this, const String *compare)
 {
@@ -442,9 +417,7 @@ strCmpZ(const String *this, const char *compare)
     FUNCTION_TEST_RETURN(strCmp(this, compare == NULL ? NULL : STRDEF(compare)));
 }
 
-/***********************************************************************************************************************************
-Duplicate a string from an existing string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strDup(const String *this)
 {
@@ -460,9 +433,7 @@ strDup(const String *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Is the string empty?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 strEmpty(const String *this)
 {
@@ -473,9 +444,7 @@ strEmpty(const String *this)
     FUNCTION_TEST_RETURN(strSize(this) == 0);
 }
 
-/***********************************************************************************************************************************
-Does the string end with the specified string?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 strEndsWith(const String *this, const String *endsWith)
 {
@@ -511,8 +480,6 @@ strEndsWithZ(const String *this, const char *endsWith)
 }
 
 /***********************************************************************************************************************************
-Are two strings equal?
-
 There are two separate implementations because string objects can get the size very efficiently whereas the zero-terminated strings
 would need a call to strlen().
 ***********************************************************************************************************************************/
@@ -551,9 +518,7 @@ strEqZ(const String *this, const char *compare)
     FUNCTION_TEST_RETURN(strcmp(strPtr(this), compare) == 0);
 }
 
-/***********************************************************************************************************************************
-Upper-case the first letter
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strFirstUpper(String *this)
 {
@@ -569,9 +534,7 @@ strFirstUpper(String *this)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Lower-case the first letter
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strFirstLower(String *this)
 {
@@ -587,9 +550,7 @@ strFirstLower(String *this)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Upper-case entire string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strUpper(String *this)
 {
@@ -606,9 +567,7 @@ strUpper(String *this)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Upper-case entire string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strLower(String *this)
 {
@@ -625,9 +584,7 @@ strLower(String *this)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Return the path part of a string (i.e. everything before the last / or "" if there is no /)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strPath(const String *this)
 {
@@ -648,9 +605,7 @@ strPath(const String *this)
             end - this->buffer <= 1 ? (size_t)(end - this->buffer) : (size_t)(end - this->buffer - 1)));
 }
 
-/***********************************************************************************************************************************
-Combine with a base path to get an absolute path
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strPathAbsolute(const String *this, const String *base)
 {
@@ -737,9 +692,7 @@ strPathAbsolute(const String *this, const String *base)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Return string ptr
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char *
 strPtr(const String *this)
 {
@@ -750,9 +703,7 @@ strPtr(const String *this)
     FUNCTION_TEST_RETURN(this == NULL ? NULL : this->buffer);
 }
 
-/***********************************************************************************************************************************
-Quote a string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strQuote(const String *this, const String *quote)
 {
@@ -781,9 +732,7 @@ strQuoteZ(const String *this, const char *quote)
     FUNCTION_TEST_RETURN(strNewFmt("%s%s%s", quote, strPtr(this), quote));
 }
 
-/***********************************************************************************************************************************
-Replace a character with another character
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strReplaceChr(String *this, char find, char replace)
 {
@@ -804,9 +753,7 @@ strReplaceChr(String *this, char find, char replace)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Return a substring given only the start position
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strSub(const String *this, size_t start)
 {
@@ -821,9 +768,7 @@ strSub(const String *this, size_t start)
     FUNCTION_TEST_RETURN(strSubN(this, start, this->size - start));
 }
 
-/***********************************************************************************************************************************
-Return a substring given the start position and size
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strSubN(const String *this, size_t start, size_t size)
 {
@@ -840,9 +785,7 @@ strSubN(const String *this, size_t start, size_t size)
     FUNCTION_TEST_RETURN(strNewN(this->buffer + start, size));
 }
 
-/***********************************************************************************************************************************
-Return string size
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 size_t
 strSize(const String *this)
 {
@@ -855,9 +798,7 @@ strSize(const String *this)
     FUNCTION_TEST_RETURN(this->size);
 }
 
-/***********************************************************************************************************************************
-Trim whitespace from the beginning and end of a string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strTrim(String *this)
 {
@@ -907,9 +848,7 @@ strTrim(String *this)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Return the index to the location of the the first occurrence of a character within a string, else -1
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 strChr(const String *this, char chr)
 {
@@ -933,9 +872,7 @@ strChr(const String *this, char chr)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Truncate the end of a string from the index provided to the current end (e.g. 123KB pass index of K returns 123)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strTrunc(String *this, int idx)
 {
@@ -980,18 +917,14 @@ size_t strObjToLog(const void *object, StrObjToLogFormat formatFunc, char *buffe
     return result;
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strToLog(const String *this)
 {
     return this == NULL ? strDup(NULL_STR) : strNewFmt("{\"%s\"}", strPtr(this));
 }
 
-/***********************************************************************************************************************************
-Format sizes (file, buffer, etc.) in human-readable form
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strSizeFormat(const uint64_t size)
 {
