@@ -38,50 +38,115 @@ typedef struct String String;
 #include "common/type/buffer.h"
 
 /***********************************************************************************************************************************
-Functions
+Constructors
 ***********************************************************************************************************************************/
+// Create a new string from a zero-terminated string
 String *strNew(const char *string);
+
+// Create a new string from a buffer. If the buffer has a NULL character this may not work as expected. All the data will be copied
+// but only the data before the NULL character will be used as a string.
 String *strNewBuf(const Buffer *buffer);
+
+// Create a new string from a format string with parameters (i.e. sprintf)
 String *strNewFmt(const char *format, ...) __attribute__((format(printf, 1, 2)));
+
+// Create a new string from a string with a specific length. The string may or may not be zero-terminated but we'll use that
+// nomenclature since we're not concerned about the end of the string.
 String *strNewN(const char *string, size_t size);
 
+// Duplicate a string
+String *strDup(const String *this);
+
+/***********************************************************************************************************************************
+Functions
+***********************************************************************************************************************************/
+// Return the file part of a string (i.e. everything after the last / or the entire string if there is no /)
 String *strBase(const String *this);
+
+// Does the string begin with the specified string?
 bool strBeginsWith(const String *this, const String *beginsWith);
 bool strBeginsWithZ(const String *this, const char *beginsWith);
+
+// Append a string
 String *strCat(String *this, const char *cat);
+
+// Append a character
 String *strCatChr(String *this, char cat);
+
+// Append a formatted string
 String *strCatFmt(String *this, const char *format, ...) __attribute__((format(printf, 2, 3)));
 
 // Append N characters from a zero-terminated string. Note that the string does not actually need to be zero-terminated as long as
 // N is <= the end of the string being concatenated.
 String *strCatZN(String *this, const char *cat, size_t size);
 
+// Return the index to the location of the the first occurrence of a character within a string, else -1
+int strChr(const String *this, char chr);
+
+// C-style string compare
 int strCmp(const String *this, const String *compare);
 int strCmpZ(const String *this, const char *compare);
-String *strDup(const String *this);
+
+// Is the string empty?
 bool strEmpty(const String *this);
+
+// Does the string end with the specified string?
 bool strEndsWith(const String *this, const String *endsWith);
 bool strEndsWithZ(const String *this, const char *endsWith);
+
+// Are two strings equal?
 bool strEq(const String *this, const String *compare);
 bool strEqZ(const String *this, const char *compare);
+
+// Upper-case the first letter
 String *strFirstUpper(String *this);
+
+// Lower-case the first letter
 String *strFirstLower(String *this);
+
+// Upper-case entire string
 String *strUpper(String *this);
+
+// Upper-case entire string
 String *strLower(String *this);
+
+// Return the path part of a string (i.e. everything before the last / or "" if there is no /)
 String *strPath(const String *this);
+
+// Combine with a base path to get an absolute path
 String *strPathAbsolute(const String *this, const String *base);
+
+// String pointer
 const char *strPtr(const String *this);
+
+// Quote a string
 String *strQuote(const String *this, const String *quote);
 String *strQuoteZ(const String *this, const char *quote);
+
+// Replace a character with another character
 String *strReplaceChr(String *this, char find, char replace);
+
+// String size minus null-terminator, i.e. the same value that strlen() would return
 size_t strSize(const String *this);
-String *strSub(const String *this, size_t start);
-String *strSubN(const String *this, size_t start, size_t size);
-String *strTrim(String *this);
-int strChr(const String *this, char chr);
-String *strTrunc(String *this, int idx);
+
+// Format sizes (file, buffer, etc.) in human-readable form
 String *strSizeFormat(const uint64_t fileSize);
 
+// Return a substring given only the start position
+String *strSub(const String *this, size_t start);
+
+// Return a substring given the start position and size
+String *strSubN(const String *this, size_t start, size_t size);
+
+// Trim whitespace from the beginning and end of a string
+String *strTrim(String *this);
+
+// Truncate the end of a string from the index provided to the current end (e.g. 123KB pass index of K returns 123)
+String *strTrunc(String *this, int idx);
+
+/***********************************************************************************************************************************
+Destructor
+***********************************************************************************************************************************/
 void strFree(String *this);
 
 /***********************************************************************************************************************************
