@@ -65,9 +65,7 @@ strLstInsertInternal(StringList *this, unsigned int listIdx, String *string)
     FUNCTION_TEST_RETURN(*(String **)lstInsert((List *)this, listIdx, &string));
 }
 
-/***********************************************************************************************************************************
-Split a string into a string list based on a delimiter
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstNewSplit(const String *string, const String *delimiter)
 {
@@ -126,12 +124,7 @@ strLstNewSplitZ(const String *string, const char *delimiter)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Split a string into a string list based on a delimiter and max size per item
-
-In other words each item in the list will be no longer than size even if multiple delimiters are skipped.  This is useful for
-breaking up test on spaces, for example.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstNewSplitSize(const String *string, const String *delimiter, size_t size)
 {
@@ -210,9 +203,7 @@ strLstNewSplitSizeZ(const String *string, const char *delimiter, size_t size)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-New string list from a variant list -- all variants in the list must be type string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstNewVarLst(const VariantList *sourceList)
 {
@@ -239,9 +230,7 @@ strLstNewVarLst(const VariantList *sourceList)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Duplicate a string list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstDup(const StringList *sourceList)
 {
@@ -268,9 +257,7 @@ strLstDup(const StringList *sourceList)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Does the specified string exist in the list?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 strLstExists(const StringList *this, const String *string)
 {
@@ -299,9 +286,7 @@ strLstExistsZ(const StringList *this, const char *cstring)
     FUNCTION_TEST_RETURN(lstExists((List *)this, &string));
 }
 
-/***********************************************************************************************************************************
-Add String to the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strLstAdd(StringList *this, const String *string)
 {
@@ -341,9 +326,6 @@ strLstAddIfMissing(StringList *this, const String *string)
     FUNCTION_TEST_RETURN(*result);
 }
 
-/***********************************************************************************************************************************
-Add a zero-terminated string to the list
-***********************************************************************************************************************************/
 String *
 strLstAddZ(StringList *this, const char *string)
 {
@@ -365,9 +347,7 @@ strLstAddZ(StringList *this, const char *string)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Wrapper for lstGet()
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strLstGet(const StringList *this, unsigned int listIdx)
 {
@@ -381,9 +361,7 @@ strLstGet(const StringList *this, unsigned int listIdx)
     FUNCTION_TEST_RETURN(*(String **)lstGet((List *)this, listIdx));
 }
 
-/***********************************************************************************************************************************
-Insert String into the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strLstInsert(StringList *this, unsigned int listIdx, const String *string)
 {
@@ -406,9 +384,6 @@ strLstInsert(StringList *this, unsigned int listIdx, const String *string)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Insert zero-terminated string into the list
-***********************************************************************************************************************************/
 String *
 strLstInsertZ(StringList *this, unsigned int listIdx, const char *string)
 {
@@ -431,9 +406,7 @@ strLstInsertZ(StringList *this, unsigned int listIdx, const char *string)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Join a list of strings into a single string using the specified separator
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strLstJoin(const StringList *this, const char *separator)
 {
@@ -448,9 +421,7 @@ strLstJoin(const StringList *this, const char *separator)
     FUNCTION_TEST_RETURN(strLstJoinQuote(this, separator, ""));
 }
 
-/***********************************************************************************************************************************
-Join a list of strings into a single string using the specified separator and quote with specified quote character
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strLstJoinQuote(const StringList *this, const char *separator, const char *quote)
 {
@@ -480,11 +451,7 @@ strLstJoinQuote(const StringList *this, const char *separator, const char *quote
     FUNCTION_TEST_RETURN(join);
 }
 
-/***********************************************************************************************************************************
-Return all items in this list which are not in the anti list
-
-The input lists must *both* be sorted ascending or the results will be unpredictable.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstMergeAnti(const StringList *this, const StringList *anti)
 {
@@ -538,16 +505,14 @@ strLstMergeAnti(const StringList *this, const StringList *anti)
                 strLstAdd(result, listItem);
         }
 
-        strLstMove(result, MEM_CONTEXT_OLD());
+        strLstMove(result, memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Move the string list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstMove(StringList *this, MemContext *parentNew)
 {
@@ -563,10 +528,7 @@ strLstMove(StringList *this, MemContext *parentNew)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Return a null-terminated array of pointers to the zero-terminated strings in this list.  DO NOT override const and modify any of the
-strings in this array, though it is OK to modify the array itself.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const char **
 strLstPtr(const StringList *this)
 {
@@ -591,9 +553,7 @@ strLstPtr(const StringList *this)
     FUNCTION_TEST_RETURN(list);
 }
 
-/***********************************************************************************************************************************
-Remove an item from the list
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 strLstRemove(StringList *this, const String *item)
 {
@@ -621,9 +581,7 @@ strLstRemoveIdx(StringList *this, unsigned int listIdx)
     FUNCTION_TEST_RETURN((StringList *)lstRemoveIdx((List *)this, listIdx));
 }
 
-/***********************************************************************************************************************************
-Wrapper for lstSize()
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 strLstSize(const StringList *this)
 {
@@ -636,9 +594,7 @@ strLstSize(const StringList *this)
     FUNCTION_TEST_RETURN(lstSize((List *)this));
 }
 
-/***********************************************************************************************************************************
-Sort strings in alphabetical order
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstSort(StringList *this, SortOrder sortOrder)
 {
@@ -654,9 +610,7 @@ strLstSort(StringList *this, SortOrder sortOrder)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Set a new comparator
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StringList *
 strLstComparatorSet(StringList *this, ListComparator *comparator)
 {
@@ -670,18 +624,14 @@ strLstComparatorSet(StringList *this, ListComparator *comparator)
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 strLstToLog(const StringList *this)
 {
     return strNewFmt("{[%s]}", strPtr(strLstJoinQuote(this, ", ", "\"")));
 }
 
-/***********************************************************************************************************************************
-Wrapper for lstFree()
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 strLstFree(StringList *this)
 {
