@@ -113,9 +113,7 @@ static const char *const variantTypeName[] =
     "VariantList",                                                  // varTypeVariantList
 };
 
-/***********************************************************************************************************************************
-Duplicate a variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varDup(const Variant *this)
 {
@@ -197,9 +195,7 @@ varDup(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Test if variants are equal
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 varEq(const Variant *this1, const Variant *this2)
 {
@@ -272,9 +268,7 @@ varEq(const Variant *this1, const Variant *this2)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Get variant type
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 VariantType
 varType(const Variant *this)
 {
@@ -287,9 +281,7 @@ varType(const Variant *this)
     FUNCTION_TEST_RETURN(this->type);
 }
 
-/***********************************************************************************************************************************
-New bool variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewBool(bool data)
 {
@@ -310,9 +302,7 @@ varNewBool(bool data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return bool
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 varBool(const Variant *this)
 {
@@ -326,9 +316,6 @@ varBool(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantBool *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return bool regardless of variant type
-***********************************************************************************************************************************/
 bool
 varBoolForce(const Variant *this)
 {
@@ -396,9 +383,7 @@ varBoolForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New double variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewDbl(double data)
 {
@@ -419,9 +404,7 @@ varNewDbl(double data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return double
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 double
 varDbl(const Variant *this)
 {
@@ -435,9 +418,6 @@ varDbl(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantDouble *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return double regardless of variant type
-***********************************************************************************************************************************/
 double
 varDblForce(const Variant *this)
 {
@@ -500,9 +480,7 @@ varDblForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New int variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewInt(int data)
 {
@@ -523,9 +501,7 @@ varNewInt(int data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return int
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int
 varInt(const Variant *this)
 {
@@ -539,9 +515,6 @@ varInt(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantInt *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return int regardless of variant type
-***********************************************************************************************************************************/
 int
 varIntForce(const Variant *this)
 {
@@ -622,9 +595,7 @@ varIntForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New int64 variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewInt64(int64_t data)
 {
@@ -645,9 +616,7 @@ varNewInt64(int64_t data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return int64
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 int64_t
 varInt64(const Variant *this)
 {
@@ -661,9 +630,6 @@ varInt64(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantInt64 *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return int64 regardless of variant type
-***********************************************************************************************************************************/
 int64_t
 varInt64Force(const Variant *this)
 {
@@ -732,9 +698,7 @@ varInt64Force(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New unsigned int variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewUInt(unsigned int data)
 {
@@ -755,9 +719,7 @@ varNewUInt(unsigned int data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return unsigned int
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 varUInt(const Variant *this)
 {
@@ -771,9 +733,6 @@ varUInt(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantUInt *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return unsigned int regardless of variant type
-***********************************************************************************************************************************/
 unsigned int
 varUIntForce(const Variant *this)
 {
@@ -863,9 +822,7 @@ varUIntForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New uint64 variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewUInt64(uint64_t data)
 {
@@ -886,9 +843,7 @@ varNewUInt64(uint64_t data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return uint64
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 uint64_t
 varUInt64(const Variant *this)
 {
@@ -902,9 +857,6 @@ varUInt64(const Variant *this)
     FUNCTION_TEST_RETURN(((VariantUInt64 *)this)->data);
 }
 
-/***********************************************************************************************************************************
-Return uint64 regardless of variant type
-***********************************************************************************************************************************/
 uint64_t
 varUInt64Force(const Variant *this)
 {
@@ -983,11 +935,7 @@ varUInt64Force(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New key/value variant
-
-Note that the kv is not duped because it this a heavy-weight operation.  It is merely moved into the same MemContext as the Variant.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewKv(KeyValue *data)
 {
@@ -1010,9 +958,7 @@ varNewKv(KeyValue *data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return key/value
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 KeyValue *
 varKv(const Variant *this)
 {
@@ -1031,9 +977,7 @@ varKv(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New string variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewStr(const String *data)
 {
@@ -1054,9 +998,6 @@ varNewStr(const String *data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-New string variant from a zero-terminated string
-***********************************************************************************************************************************/
 Variant *
 varNewStrZ(const char *data)
 {
@@ -1067,9 +1008,7 @@ varNewStrZ(const char *data)
     FUNCTION_TEST_RETURN(varNewStr(data == NULL ? NULL : strNew(data)));
 }
 
-/***********************************************************************************************************************************
-Return string
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 varStr(const Variant *this)
 {
@@ -1088,9 +1027,6 @@ varStr(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Return string regardless of variant type
-***********************************************************************************************************************************/
 String *
 varStrForce(const Variant *this)
 {
@@ -1168,9 +1104,7 @@ varStrForce(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-New variant list variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Variant *
 varNewVarLst(const VariantList *data)
 {
@@ -1193,9 +1127,7 @@ varNewVarLst(const VariantList *data)
     FUNCTION_TEST_RETURN((Variant *)this);
 }
 
-/***********************************************************************************************************************************
-Return key/value
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 VariantList *
 varVarLst(const Variant *this)
 {
@@ -1214,9 +1146,7 @@ varVarLst(const Variant *this)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Convert variant to a zero-terminated string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 varToLog(const Variant *this)
 {
@@ -1262,9 +1192,7 @@ varToLog(const Variant *this)
     return result;
 }
 
-/***********************************************************************************************************************************
-Free variant
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 varFree(Variant *this)
 {
