@@ -6,7 +6,7 @@ Database Client
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "common/wait.h"
 #include "db/db.h"
 #include "db/protocol.h"
@@ -52,9 +52,7 @@ OBJECT_DEFINE_FREE_RESOURCE_BEGIN(DB, LOG, logLevelTrace)
 }
 OBJECT_DEFINE_FREE_RESOURCE_END(LOG);
 
-/***********************************************************************************************************************************
-Create object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Db *
 dbNew(PgClient *client, ProtocolClient *remoteClient, const String *applicationName)
 {
@@ -72,11 +70,15 @@ dbNew(PgClient *client, ProtocolClient *remoteClient, const String *applicationN
     MEM_CONTEXT_NEW_BEGIN("Db")
     {
         this = memNew(sizeof(Db));
-        this->memContext = memContextCurrent();
+
+        *this = (Db)
+        {
+            .memContext = memContextCurrent(),
+            .remoteClient = remoteClient,
+            .applicationName = strDup(applicationName),
+        };
 
         this->client = pgClientMove(client, this->memContext);
-        this->remoteClient = remoteClient;
-        this->applicationName = strDup(applicationName);
     }
     MEM_CONTEXT_NEW_END();
 
@@ -177,9 +179,7 @@ dbQueryRow(Db *this, const String *query)
     FUNCTION_LOG_RETURN(VARIANT_LIST, varVarLst(varLstGet(result, 0)));
 }
 
-/***********************************************************************************************************************************
-Open the db connection
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 dbOpen(Db *this)
 {
@@ -207,6 +207,9 @@ dbOpen(Db *this)
         // but this is an extra level protection.
         dbExec(this, STRDEF("set search_path = 'pg_catalog'"));
 
+        // Set client encoding to UTF8.  This is the only encoding (other than ASCII) that we can safely work with.
+        dbExec(this, STRDEF("set client_encoding = 'UTF8'"));
+
         // Query the version and data_directory
         VariantList *row = dbQueryRow(
             this,
@@ -307,16 +310,20 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
         // If stop-auto is enabled check for a running backup
         if (stopAuto)
         {
-            // This feature is not supported for PostgreSQL >= 9.6 since backups are run in non-exclusive mode
-            CHECK(dbPgVersion(this) >= PG_VERSION_93 && dbPgVersion(this) < PG_VERSION_96);
+            // Feature is not supported in PostgreSQL < 9.3
+            CHECK(dbPgVersion(this) >= PG_VERSION_93);
 
-            if (varBool(dbQueryColumn(this, STRDEF("select pg_catalog.pg_is_in_backup()::bool"))))
+            // Feature is not needed for PostgreSQL >= 9.6 since backups are run in non-exclusive mode
+            if (dbPgVersion(this) < PG_VERSION_96)
             {
-                LOG_WARN(
-                    "the cluster is already in backup mode but no " PROJECT_NAME " backup process is running."
-                    " pg_stop_backup() will be called so a new backup can be started.");
+                if (varBool(dbQueryColumn(this, STRDEF("select pg_catalog.pg_is_in_backup()::bool"))))
+                {
+                    LOG_WARN(
+                        "the cluster is already in backup mode but no " PROJECT_NAME " backup process is running."
+                        " pg_stop_backup() will be called so a new backup can be started.");
 
-                dbBackupStop(this);
+                    dbBackupStop(this);
+                }
             }
         }
 
@@ -324,10 +331,12 @@ dbBackupStart(Db *this, bool startFast, bool stopAuto)
         VariantList *row = dbQueryRow(this, dbBackupStartQuery(dbPgVersion(this), startFast));
 
         // Return results
-        memContextSwitch(MEM_CONTEXT_OLD());
-        result.lsn = strDup(varStr(varLstGet(row, 0)));
-        result.walSegmentName = strDup(varStr(varLstGet(row, 1)));
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result.lsn = strDup(varStr(varLstGet(row, 0)));
+            result.walSegmentName = strDup(varStr(varLstGet(row, 1)));
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
@@ -407,29 +416,27 @@ dbBackupStop(Db *this)
             dbPgVersion(this) >= PG_VERSION_96 ? strSize(strTrim(strDup(varStr(varLstGet(row, 3))))) == 0 : false;
 
         // Return results
-        memContextSwitch(MEM_CONTEXT_OLD());
-
-        result.lsn = strDup(varStr(varLstGet(row, 0)));
-        result.walSegmentName = strDup(varStr(varLstGet(row, 1)));
-
-        if (dbPgVersion(this) >= PG_VERSION_96)
+        MEM_CONTEXT_PRIOR_BEGIN()
         {
-            result.backupLabel = strDup(varStr(varLstGet(row, 2)));
+            result.lsn = strDup(varStr(varLstGet(row, 0)));
+            result.walSegmentName = strDup(varStr(varLstGet(row, 1)));
 
-            if (!tablespaceMapEmpty)
-                result.tablespaceMap = strDup(varStr(varLstGet(row, 3)));
+            if (dbPgVersion(this) >= PG_VERSION_96)
+            {
+                result.backupLabel = strDup(varStr(varLstGet(row, 2)));
+
+                if (!tablespaceMapEmpty)
+                    result.tablespaceMap = strDup(varStr(varLstGet(row, 3)));
+            }
         }
-
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(DB_BACKUP_STOP_RESULT, result);
 }
 
-/***********************************************************************************************************************************
-Is this instance a standby?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 dbIsStandby(Db *this)
 {
@@ -598,9 +605,7 @@ dbTimeMSec(Db *this)
         TIME_MSEC, varUInt64Force(dbQueryColumn(this, STRDEF("select (extract(epoch from clock_timestamp()) * 1000)::bigint"))));
 }
 
-/***********************************************************************************************************************************
-Switch the WAL segment and return the segment that should have been archived
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 dbWalSwitch(Db *this)
 {
@@ -624,19 +629,19 @@ dbWalSwitch(Db *this)
         const String *walFileName = varStr(
             dbQueryColumn(this, strNewFmt("select pg_catalog.pg_%sfile_name(pg_catalog.pg_switch_%s())::text", walName, walName)));
 
-        // Copy WAL segment name to the calling context
-        memContextSwitch(MEM_CONTEXT_OLD());
-        result = strDup(walFileName);
-        memContextSwitch(MEM_CONTEXT_TEMP());
+        // Copy WAL segment name to the prior context
+        MEM_CONTEXT_PRIOR_BEGIN()
+        {
+            result = strDup(walFileName);
+        }
+        MEM_CONTEXT_PRIOR_END();
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(STRING, result);
 }
 
-/***********************************************************************************************************************************
-Get pg data path loaded from the data_directory GUC
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 dbPgDataPath(const Db *this)
 {
@@ -649,9 +654,7 @@ dbPgDataPath(const Db *this)
     FUNCTION_TEST_RETURN(this->pgDataPath);
 }
 
-/***********************************************************************************************************************************
-Get pg version loaded from the server_version_num GUC
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 dbPgVersion(const Db *this)
 {
@@ -664,9 +667,7 @@ dbPgVersion(const Db *this)
     FUNCTION_TEST_RETURN(this->pgVersion);
 }
 
-/***********************************************************************************************************************************
-Get pg version loaded from the server_version_num GUC
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 dbArchiveMode(const Db *this)
 {
@@ -679,9 +680,7 @@ dbArchiveMode(const Db *this)
     FUNCTION_TEST_RETURN(this->archiveMode);
 }
 
-/***********************************************************************************************************************************
-Get pg version loaded from the server_version_num GUC
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 dbArchiveCommand(const Db *this)
 {
@@ -694,9 +693,7 @@ dbArchiveCommand(const Db *this)
     FUNCTION_TEST_RETURN(this->archiveCommand);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 dbToLog(const Db *this)
 {
