@@ -15,8 +15,8 @@ Info Handler
 #include "common/ini.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
 #include "common/type/json.h"
+#include "common/type/object.h"
 #include "info/info.h"
 #include "storage/helper.h"
 #include "version.h"
@@ -82,13 +82,12 @@ BUFFER_STRDEF_STATIC(INFO_CHECKSUM_SECTION_NEXT_END_BUF, "},");
     }                                                                                                                              \
     while (0)
 
-BUFFER_STRDEF_STATIC(INFO_CHECKSUM_KEY_VALUE_END_BUF, "\":");
+BUFFER_STRDEF_STATIC(INFO_CHECKSUM_KEY_VALUE_END_BUF, ":");
 
 #define INFO_CHECKSUM_KEY_VALUE(checksum, key, value)                                                                              \
     do                                                                                                                             \
     {                                                                                                                              \
-        ioFilterProcessIn(checksum, QUOTED_BUF);                                                                                   \
-        ioFilterProcessIn(checksum, BUFSTR(key));                                                                                  \
+        ioFilterProcessIn(checksum, BUFSTR(jsonFromStr(key)));                                                                     \
         ioFilterProcessIn(checksum, INFO_CHECKSUM_KEY_VALUE_END_BUF);                                                              \
         ioFilterProcessIn(checksum, BUFSTR(value));                                                                                \
     }                                                                                                                              \
@@ -119,14 +118,16 @@ infoNewInternal(void)
     FUNCTION_TEST_VOID();
 
     Info *this = memNew(sizeof(Info));
-    this->memContext = memContextCurrent();
+
+    *this = (Info)
+    {
+        .memContext = memContextCurrent(),
+    };
 
     FUNCTION_TEST_RETURN(this);
 }
 
-/***********************************************************************************************************************************
-Create new object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Info *
 infoNew(const String *cipherPass)
 {
@@ -250,9 +251,7 @@ infoLoadCallback(void *data, const String *section, const String *key, const Str
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Create new object and load contents from a file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Info *
 infoNewLoad(IoRead *read, InfoLoadNewCallback *callbackFunction, void *callbackData)
 {
@@ -317,9 +316,7 @@ infoNewLoad(IoRead *read, InfoLoadNewCallback *callbackFunction, void *callbackD
     FUNCTION_LOG_RETURN(INFO, this);
 }
 
-/***********************************************************************************************************************************
-Check if the section should be saved
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 infoSaveSection(InfoSave *infoSaveData, const String *section, const String *sectionNext)
 {
@@ -334,9 +331,7 @@ infoSaveSection(InfoSave *infoSaveData, const String *section, const String *sec
             (sectionNext == NULL || strCmp(section, sectionNext) < 0));
 }
 
-/***********************************************************************************************************************************
-Save a JSON formatted value and update checksum
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 infoSaveValue(InfoSave *infoSaveData, const String *section, const String *key, const String *jsonValue)
 {
@@ -386,9 +381,7 @@ infoSaveValue(InfoSave *infoSaveData, const String *section, const String *key,
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Save to file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 infoSave(Info *this, IoWrite *write, InfoSaveCallback *callbackFunction, void *callbackData)
 {
@@ -448,7 +441,7 @@ infoSave(Info *this, IoWrite *write, InfoSaveCallback *callbackFunction, void *c
 }
 
 /***********************************************************************************************************************************
-Accessor functions
+Getters/Setters
 ***********************************************************************************************************************************/
 const String *
 infoCipherPass(const Info *this)
@@ -493,9 +486,7 @@ infoBackrestVersion(const Info *this)
     FUNCTION_TEST_RETURN(this->backrestVersion);
 }
 
-/***********************************************************************************************************************************
-Load info file(s) and throw error for each attempt if none are successful
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 infoLoad(const String *error, InfoLoadCallback *callbackFunction, void *callbackData)
 {
