@@ -30,6 +30,10 @@ STRING_EXTERN(PG_PATH_GLOBAL_STR,                                   PG_PATH_GLOB
 STRING_EXTERN(PG_NAME_WAL_STR,                                      PG_NAME_WAL);
 STRING_EXTERN(PG_NAME_XLOG_STR,                                     PG_NAME_XLOG);
 
+// Wal path names depending on version
+STRING_STATIC(PG_PATH_PGWAL_STR,                                    "pg_wal");
+STRING_STATIC(PG_PATH_PGXLOG_STR,                                   "pg_xlog");
+
 // Transaction commit log path names depending on version
 STRING_STATIC(PG_PATH_PGCLOG_STR,                                   "pg_clog");
 STRING_STATIC(PG_PATH_PGXACT_STR,                                   "pg_xact");
@@ -354,9 +358,7 @@ pgInterfaceVersion(unsigned int pgVersion)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Get the catalog version for a PostgreSQL version
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 uint32_t
 pgCatalogVersion(unsigned int pgVersion)
 {
@@ -367,9 +369,7 @@ pgCatalogVersion(unsigned int pgVersion)
     FUNCTION_TEST_RETURN(pgInterfaceVersion(pgVersion)->catalogVersion());
 }
 
-/***********************************************************************************************************************************
-Get info from pg_control
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 PgControl
 pgControlFromBuffer(const Buffer *controlFile)
 {
@@ -384,7 +384,7 @@ pgControlFromBuffer(const Buffer *controlFile)
 
     for (unsigned int interfaceIdx = 0; interfaceIdx < PG_INTERFACE_SIZE; interfaceIdx++)
     {
-        if (pgInterface[interfaceIdx].controlIs(bufPtr(controlFile)))
+        if (pgInterface[interfaceIdx].controlIs(bufPtrConst(controlFile)))
         {
             interface = &pgInterface[interfaceIdx];
             break;
@@ -394,7 +394,7 @@ pgControlFromBuffer(const Buffer *controlFile)
     // If the version was not found then error with the control and catalog version that were found
     if (interface == NULL)
     {
-        PgControlCommon *controlCommon = (PgControlCommon *)bufPtr(controlFile);
+        const PgControlCommon *controlCommon = (const PgControlCommon *)bufPtrConst(controlFile);
 
         THROW_FMT(
             VersionNotSupportedError,
@@ -404,7 +404,7 @@ pgControlFromBuffer(const Buffer *controlFile)
     }
 
     // Get info from the control file
-    PgControl result = interface->control(bufPtr(controlFile));
+    PgControl result = interface->control(bufPtrConst(controlFile));
     result.version = interface->version;
 
     // Check the segment size
@@ -422,9 +422,6 @@ pgControlFromBuffer(const Buffer *controlFile)
     FUNCTION_LOG_RETURN(PG_CONTROL, result);
 }
 
-/***********************************************************************************************************************************
-Get info from pg_control
-***********************************************************************************************************************************/
 PgControl
 pgControlFromFile(const Storage *storage)
 {
@@ -449,9 +446,7 @@ pgControlFromFile(const Storage *storage)
     FUNCTION_LOG_RETURN(PG_CONTROL, result);
 }
 
-/***********************************************************************************************************************************
-Get the control version for a PostgreSQL version
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 uint32_t
 pgControlVersion(unsigned int pgVersion)
 {
@@ -474,9 +469,7 @@ typedef struct PgWalCommon
 
 #define PG_WAL_LONG_HEADER                                          0x0002
 
-/***********************************************************************************************************************************
-Get info from WAL header
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 PgWal
 pgWalFromBuffer(const Buffer *walBuffer)
 {
@@ -487,7 +480,7 @@ pgWalFromBuffer(const Buffer *walBuffer)
     ASSERT(walBuffer != NULL);
 
     // Check that this is a long format WAL header
-    if (!(((PgWalCommon *)bufPtr(walBuffer))->flag & PG_WAL_LONG_HEADER))
+    if (!(((const PgWalCommon *)bufPtrConst(walBuffer))->flag & PG_WAL_LONG_HEADER))
         THROW_FMT(FormatError, "first page header in WAL file is expected to be in long format");
 
     // Search for the version of PostgreSQL that uses this WAL magic
@@ -495,7 +488,7 @@ pgWalFromBuffer(const Buffer *walBuffer)
 
     for (unsigned int interfaceIdx = 0; interfaceIdx < PG_INTERFACE_SIZE; interfaceIdx++)
     {
-        if (pgInterface[interfaceIdx].walIs(bufPtr(walBuffer)))
+        if (pgInterface[interfaceIdx].walIs(bufPtrConst(walBuffer)))
         {
             interface = &pgInterface[interfaceIdx];
             break;
@@ -509,19 +502,16 @@ pgWalFromBuffer(const Buffer *walBuffer)
             VersionNotSupportedError,
             "unexpected WAL magic %u\n"
                 "HINT: is this version of PostgreSQL supported?",
-            ((PgWalCommon *)bufPtr(walBuffer))->magic);
+            ((const PgWalCommon *)bufPtrConst(walBuffer))->magic);
     }
 
     // Get info from the control file
-    PgWal result = interface->wal(bufPtr(walBuffer));
+    PgWal result = interface->wal(bufPtrConst(walBuffer));
     result.version = interface->version;
 
     FUNCTION_LOG_RETURN(PG_WAL, result);
 }
 
-/***********************************************************************************************************************************
-Get info from a WAL segment
-***********************************************************************************************************************************/
 PgWal
 pgWalFromFile(const String *walFile)
 {
@@ -561,9 +551,11 @@ pgTablespaceId(unsigned int pgVersion)
         {
             String *pgVersionStr = pgVersionToStr(pgVersion);
 
-            memContextSwitch(MEM_CONTEXT_OLD());
-            result = strNewFmt("PG_%s_%u", strPtr(pgVersionStr), pgCatalogVersion(pgVersion));
-            memContextSwitch(MEM_CONTEXT_TEMP());
+            MEM_CONTEXT_PRIOR_BEGIN()
+            {
+                result = strNewFmt("PG_%s_%u", strPtr(pgVersionStr), pgCatalogVersion(pgVersion));
+            }
+            MEM_CONTEXT_PRIOR_END();
         }
         MEM_CONTEXT_TEMP_END();
     }
@@ -615,7 +607,67 @@ pgLsnToWalSegment(uint32_t timeline, uint64_t lsn, unsigned int walSegmentSize)
     FUNCTION_TEST_END();
 
     FUNCTION_TEST_RETURN(
-        strNewFmt("%08X%08X%08X", timeline, (unsigned int)(lsn >> 32), (unsigned int)(lsn & 0xFFFFFFFF / walSegmentSize)));
+        strNewFmt("%08X%08X%08X", timeline, (unsigned int)(lsn >> 32), (unsigned int)(lsn & 0xFFFFFFFF) / walSegmentSize));
+}
+
+/**********************************************************************************************************************************/
+StringList *
+pgLsnRangeToWalSegmentList(
+    unsigned int pgVersion, uint32_t timeline, uint64_t lsnStart, uint64_t lsnStop, unsigned int walSegmentSize)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(UINT, pgVersion);
+        FUNCTION_TEST_PARAM(UINT, timeline);
+        FUNCTION_TEST_PARAM(UINT64, lsnStart);
+        FUNCTION_TEST_PARAM(UINT64, lsnStop);
+        FUNCTION_TEST_PARAM(UINT, walSegmentSize);
+    FUNCTION_TEST_END();
+
+    ASSERT(pgVersion != 0);
+    ASSERT(timeline != 0);
+    ASSERT(lsnStart <= lsnStop);
+    ASSERT(walSegmentSize != 0);
+    ASSERT(pgVersion > PG_VERSION_92 || walSegmentSize == PG_WAL_SEGMENT_SIZE_DEFAULT);
+
+    StringList *result = NULL;
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        result = strLstNew();
+
+        // Skip the FF segment when PostgreSQL <= 9.2 (in this case segment size should always be 16MB)
+        bool skipFF = pgVersion <= PG_VERSION_92;
+
+        // Calculate the start and stop segments
+        unsigned int startMajor = (unsigned int)(lsnStart >> 32);
+        unsigned int startMinor = (unsigned int)(lsnStart & 0xFFFFFFFF) / walSegmentSize;
+
+        unsigned int stopMajor = (unsigned int)(lsnStop >> 32);
+        unsigned int stopMinor = (unsigned int)(lsnStop & 0xFFFFFFFF) / walSegmentSize;
+
+        unsigned int minorPerMajor = 0xFFFFFFFF / walSegmentSize;
+
+        // Create list
+        strLstAdd(result, strNewFmt("%08X%08X%08X", timeline, startMajor, startMinor));
+
+        while (!(startMajor == stopMajor && startMinor == stopMinor))
+        {
+            startMinor++;
+
+            if ((skipFF && startMinor == 0xFF) || (!skipFF && startMinor > minorPerMajor))
+            {
+                startMajor++;
+                startMinor = 0;
+            }
+
+            strLstAdd(result, strNewFmt("%08X%08X%08X", timeline, startMajor, startMinor));
+        }
+
+        strLstMove(result, memContextPrior());
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_TEST_RETURN(result);
 }
 
 /**********************************************************************************************************************************/
@@ -642,6 +694,17 @@ pgWalName(unsigned int pgVersion)
     FUNCTION_TEST_RETURN(pgVersion >= PG_VERSION_WAL_RENAME ? PG_NAME_WAL_STR : PG_NAME_XLOG_STR);
 }
 
+/**********************************************************************************************************************************/
+const String *
+pgWalPath(unsigned int pgVersion)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(UINT, pgVersion);
+    FUNCTION_TEST_END();
+
+    FUNCTION_TEST_RETURN(pgVersion >= PG_VERSION_WAL_RENAME ? PG_PATH_PGWAL_STR : PG_PATH_PGXLOG_STR);
+}
+
 /**********************************************************************************************************************************/
 const String *
 pgXactPath(unsigned int pgVersion)
@@ -653,9 +716,7 @@ pgXactPath(unsigned int pgVersion)
     FUNCTION_TEST_RETURN(pgVersion >= PG_VERSION_WAL_RENAME ? PG_PATH_PGXACT_STR : PG_PATH_PGCLOG_STR);
 }
 
-/***********************************************************************************************************************************
-Create pg_control for testing
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 #ifdef DEBUG
 
 Buffer *
@@ -682,9 +743,7 @@ pgControlTestToBuffer(PgControl pgControl)
 
 #endif
 
-/***********************************************************************************************************************************
-Create WAL for testing
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 #ifdef DEBUG
 
 void
@@ -705,9 +764,7 @@ pgWalTestToBuffer(PgWal pgWal, Buffer *walBuffer)
 
 #endif
 
-/***********************************************************************************************************************************
-Convert version string to version number
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 unsigned int
 pgVersionFromStr(const String *version)
 {
@@ -746,9 +803,6 @@ pgVersionFromStr(const String *version)
     FUNCTION_LOG_RETURN(UINT, result);
 }
 
-/***********************************************************************************************************************************
-Convert version number to string
-***********************************************************************************************************************************/
 String *
 pgVersionToStr(unsigned int version)
 {
@@ -762,9 +816,7 @@ pgVersionToStr(unsigned int version)
     FUNCTION_LOG_RETURN(STRING, result);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 pgControlToLog(const PgControl *pgControl)
 {
