@@ -12,7 +12,9 @@ Protocol Helper
 #include "config/config.h"
 #include "config/exec.h"
 #include "config/protocol.h"
+#include "postgres/version.h"
 #include "protocol/helper.h"
+#include "version.h"
 
 /***********************************************************************************************************************************
 Constants
@@ -20,8 +22,8 @@ Constants
 STRING_EXTERN(PROTOCOL_SERVICE_LOCAL_STR,                           PROTOCOL_SERVICE_LOCAL);
 STRING_EXTERN(PROTOCOL_SERVICE_REMOTE_STR,                          PROTOCOL_SERVICE_REMOTE);
 
-STRING_STATIC(PROTOCOL_STORAGE_TYPE_PG_STR,                         "db");
-STRING_STATIC(PROTOCOL_STORAGE_TYPE_REPO_STR,                       "backup");
+STRING_STATIC(PROTOCOL_REMOTE_TYPE_PG_STR,                          PROTOCOL_REMOTE_TYPE_PG);
+STRING_STATIC(PROTOCOL_REMOTE_TYPE_REPO_STR,                        PROTOCOL_REMOTE_TYPE_REPO);
 
 /***********************************************************************************************************************************
 Local variables
@@ -55,15 +57,17 @@ protocolHelperInit(void)
         // Create a mem context to store protocol objects
         MEM_CONTEXT_BEGIN(memContextTop())
         {
-            protocolHelper.memContext = memContextNew("ProtocolHelper");
+            MEM_CONTEXT_NEW_BEGIN("ProtocolHelper")
+            {
+                protocolHelper.memContext = MEM_CONTEXT_NEW();
+            }
+            MEM_CONTEXT_NEW_END();
         }
         MEM_CONTEXT_END();
     }
 }
 
-/***********************************************************************************************************************************
-Is the repository local?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 repoIsLocal(void)
 {
@@ -71,9 +75,7 @@ repoIsLocal(void)
     FUNCTION_TEST_RETURN(!cfgOptionTest(cfgOptRepoHost));
 }
 
-/***********************************************************************************************************************************
-Error if the repository is not local
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 repoIsLocalVerify(void)
 {
@@ -85,9 +87,7 @@ repoIsLocalVerify(void)
     FUNCTION_TEST_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Is pg local?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 pgIsLocal(unsigned int hostId)
 {
@@ -100,6 +100,18 @@ pgIsLocal(unsigned int hostId)
     FUNCTION_LOG_RETURN(BOOL, !cfgOptionTest(cfgOptPgHost + hostId - 1));
 }
 
+/**********************************************************************************************************************************/
+void
+pgIsLocalVerify(void)
+{
+    FUNCTION_TEST_VOID();
+
+    if (!pgIsLocal(1))
+        THROW_FMT(HostInvalidError, "%s command must be run on the " PG_NAME " host", cfgCommandName(cfgCommand()));
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
 /***********************************************************************************************************************************
 Get the command line required for local protocol execution
 ***********************************************************************************************************************************/
@@ -121,17 +133,14 @@ protocolLocalParam(ProtocolStorageType protocolStorageType, unsigned int hostId,
         // Option replacements
         KeyValue *optionReplace = kvNew();
 
-        // Add the command option
-        kvPut(optionReplace, VARSTR(CFGOPT_COMMAND_STR), VARSTRZ(cfgCommandName(cfgCommand())));
-
         // Add the process id -- used when more than one process will be called
         kvPut(optionReplace, VARSTR(CFGOPT_PROCESS_STR), VARUINT(protocolId));
 
         // Add the host id
         kvPut(optionReplace, VARSTR(CFGOPT_HOST_ID_STR), VARUINT(hostId));
 
-        // Add the storage type
-        kvPut(optionReplace, VARSTR(CFGOPT_TYPE_STR), VARSTR(protocolStorageTypeStr(protocolStorageType)));
+        // Add the remote type
+        kvPut(optionReplace, VARSTR(CFGOPT_REMOTE_TYPE_STR), VARSTR(protocolStorageTypeStr(protocolStorageType)));
 
         // Only enable file logging on the local when requested
         kvPut(
@@ -141,16 +150,17 @@ protocolLocalParam(ProtocolStorageType protocolStorageType, unsigned int hostId,
         // Always output errors on stderr for debugging purposes
         kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_STDERR_STR), VARSTRDEF("error"));
 
-        result = strLstMove(cfgExecParam(cfgCmdLocal, optionReplace, true), MEM_CONTEXT_OLD());
+        // Disable output to stdout since it is used by the protocol
+        kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_CONSOLE_STR), VARSTRDEF("off"));
+
+        result = strLstMove(cfgExecParam(cfgCommand(), cfgCmdRoleLocal, optionReplace, true, false), memContextPrior());
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(STRING_LIST, result);
 }
 
-/***********************************************************************************************************************************
-Get the local protocol client
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 ProtocolClient *
 protocolLocalGet(ProtocolStorageType protocolStorageType, unsigned int hostId, unsigned int protocolId)
 {
@@ -170,8 +180,10 @@ protocolLocalGet(ProtocolStorageType protocolStorageType, unsigned int hostId, u
         MEM_CONTEXT_BEGIN(protocolHelper.memContext)
         {
             protocolHelper.clientLocalSize = cfgOptionUInt(cfgOptProcessMax) + 1;
-            protocolHelper.clientLocal = (ProtocolHelperClient *)memNew(
-                protocolHelper.clientLocalSize * sizeof(ProtocolHelperClient));
+            protocolHelper.clientLocal = memNew(protocolHelper.clientLocalSize * sizeof(ProtocolHelperClient));
+
+            for (unsigned int clientIdx = 0; clientIdx < protocolHelper.clientLocalSize; clientIdx++)
+                protocolHelper.clientLocal[clientIdx] = (ProtocolHelperClient){.exec = NULL};
         }
         MEM_CONTEXT_END();
     }
@@ -265,32 +277,68 @@ protocolRemoteParam(ProtocolStorageType protocolStorageType, unsigned int protoc
         optionReplace, VARSTR(CFGOPT_CONFIG_PATH_STR),
         cfgOptionSource(optConfigPath) != cfgSourceDefault ? cfgOption(optConfigPath) : NULL);
 
-    // Use a C remote
-    kvPut(optionReplace, VARSTR(CFGOPT_C_STR), VARBOOL(true));
+    // Update/remove repo/pg options that are sent to the remote
+    const String *repoHostPrefix = STR(cfgDefOptionName(cfgDefOptRepoHost));
+    const String *repoPrefix = strNewFmt("%s-", PROTOCOL_REMOTE_TYPE_REPO);
+    const String *pgHostPrefix = STR(cfgDefOptionName(cfgDefOptPgHost));
+    const String *pgPrefix = strNewFmt("%s-", PROTOCOL_REMOTE_TYPE_PG);
 
-    // Copy pg options to index 0 since that's what the remote will be expecting
-    if (hostIdx != 0)
+    for (ConfigOption optionId = 0; optionId < CFG_OPTION_TOTAL; optionId++)
     {
-        kvPut(optionReplace, VARSTR(CFGOPT_PG1_PATH_STR), cfgOption(cfgOptPgPath + hostIdx));
-        kvPut(
-            optionReplace, VARSTR(CFGOPT_PG1_SOCKET_PATH_STR),
-            cfgOptionSource(cfgOptPgSocketPath + hostIdx) != cfgSourceDefault ? cfgOption(cfgOptPgSocketPath + hostIdx) : NULL);
-        kvPut(
-            optionReplace, VARSTR(CFGOPT_PG1_PORT_STR),
-            cfgOptionSource(cfgOptPgPort + hostIdx) != cfgSourceDefault ? cfgOption(cfgOptPgPort + hostIdx) : NULL);
+        const String *optionDefName = STR(cfgDefOptionName(cfgOptionDefIdFromId(optionId)));
+        bool remove = false;
+
+        // Remove repo host options that are not needed on the remote.  The remote is not expecting to see host settings and it
+        // could get confused about the locality of the repo, i.e. local or remote.
+        if (strBeginsWith(optionDefName, repoHostPrefix))
+        {
+            remove = true;
+        }
+        // Remove repo options when the remote type is pg since they won't be used
+        else if (strBeginsWith(optionDefName, repoPrefix))
+        {
+            if (protocolStorageType == protocolStorageTypePg)
+                remove = true;
+        }
+        // Remove pg host options that are not needed on the remote.  The remote is not expecting to see host settings and it could
+        // get confused about the locality of pg, i.e. local or remote.
+        else if (strBeginsWith(optionDefName, pgHostPrefix))
+        {
+            remove = true;
+        }
+        else if (strBeginsWith(optionDefName, pgPrefix))
+        {
+            // Remove pg options when the remote type is repo since they won't be used
+            if (protocolStorageType == protocolStorageTypeRepo)
+            {
+                remove = true;
+            }
+            // Else move/remove pg options with index > 0 since they won't be used
+            else if (cfgOptionIndex(optionId) > 0)
+            {
+                // If the option index matches the host-id then this is a pg option that the remote needs.  Since the remote expects
+                // to find pg options in index 0, copy the option to index 0.
+                if (cfgOptionIndex(optionId) == hostIdx)
+                {
+                    kvPut(
+                        optionReplace, VARSTRZ(cfgOptionName(optionId - hostIdx)),
+                        cfgOptionSource(optionId) != cfgSourceDefault ? cfgOption(optionId) : NULL);
+                }
+
+                // Remove pg options that are not needed on the remote.  The remote is only going to look at index 0 so the options
+                // in higher indexes will not be used and just add clutter which makes debugging harder.
+                remove = true;
+            }
+        }
+
+        // Remove options that have been marked for removal if they are not already null or invalid. This is more efficient because
+        // cfgExecParam() won't have to search through as large a list looking for overrides.
+        if (remove && cfgOptionTest(optionId))
+            kvPut(optionReplace, VARSTRZ(cfgOptionName(optionId)), NULL);
     }
 
-    // Remove pg options that are not needed on the remote.  This is to reduce clustter and make debugging options easier.
-    for (unsigned int pgIdx = 1; pgIdx < cfgOptionIndexTotal(cfgOptPgPath); pgIdx++)
-    {
-        kvPut(optionReplace, VARSTRZ(cfgOptionName(cfgOptPgPath + pgIdx)), NULL);
-        kvPut(optionReplace, VARSTRZ(cfgOptionName(cfgOptPgSocketPath + pgIdx)), NULL);
-        kvPut(optionReplace, VARSTRZ(cfgOptionName(cfgOptPgPort + pgIdx)), NULL);
-    }
-
-    // Add the command option (or use the current command option if it is valid)
-    if (!cfgOptionTest(cfgOptCommand))
-        kvPut(optionReplace, VARSTR(CFGOPT_COMMAND_STR), VARSTRZ(cfgCommandName(cfgCommand())));
+    // Don't pass host-id to the remote.  The host will always be in index 0.
+    kvPut(optionReplace, VARSTR(CFGOPT_HOST_ID_STR), NULL);
 
     // Add the process id (or use the current process id if it is valid)
     if (!cfgOptionTest(cfgOptProcess))
@@ -300,6 +348,17 @@ protocolRemoteParam(ProtocolStorageType protocolStorageType, unsigned int protoc
     kvPut(optionReplace, VARSTR(CFGOPT_LOG_PATH_STR), NULL);
     kvPut(optionReplace, VARSTR(CFGOPT_LOCK_PATH_STR), NULL);
 
+    // ??? Don't pass restore options which the remote doesn't need and are likely to contain spaces because they might get mangled
+    // on the way to the remote depending on how SSH is set up on the server.  This code should be removed when option passing with
+    // spaces is resolved.
+    kvPut(optionReplace, VARSTR(CFGOPT_TYPE_STR), NULL);
+    kvPut(optionReplace, VARSTR(CFGOPT_TARGET_STR), NULL);
+    kvPut(optionReplace, VARSTR(CFGOPT_TARGET_EXCLUSIVE_STR), NULL);
+    kvPut(optionReplace, VARSTR(CFGOPT_TARGET_ACTION_STR), NULL);
+    kvPut(optionReplace, VARSTR(CFGOPT_TARGET_STR), NULL);
+    kvPut(optionReplace, VARSTR(CFGOPT_TARGET_TIMELINE_STR), NULL);
+    kvPut(optionReplace, VARSTR(CFGOPT_RECOVERY_OPTION_STR), NULL);
+
     // Only enable file logging on the remote when requested
     kvPut(
         optionReplace, VARSTR(CFGOPT_LOG_LEVEL_FILE_STR),
@@ -308,19 +367,20 @@ protocolRemoteParam(ProtocolStorageType protocolStorageType, unsigned int protoc
     // Always output errors on stderr for debugging purposes
     kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_STDERR_STR), VARSTRDEF("error"));
 
-    // Add the type
-    kvPut(optionReplace, VARSTR(CFGOPT_TYPE_STR), VARSTR(protocolStorageTypeStr(protocolStorageType)));
+    // Disable output to stdout since it is used by the protocol
+    kvPut(optionReplace, VARSTR(CFGOPT_LOG_LEVEL_CONSOLE_STR), VARSTRDEF("off"));
 
-    StringList *commandExec = cfgExecParam(cfgCmdRemote, optionReplace, false);
+    // Add the remote type
+    kvPut(optionReplace, VARSTR(CFGOPT_REMOTE_TYPE_STR), VARSTR(protocolStorageTypeStr(protocolStorageType)));
+
+    StringList *commandExec = cfgExecParam(cfgCommand(), cfgCmdRoleRemote, optionReplace, false, true);
     strLstInsert(commandExec, 0, cfgOptionStr(isRepo ? cfgOptRepoHostCmd : cfgOptPgHostCmd + hostIdx));
     strLstAdd(result, strLstJoin(commandExec, " "));
 
     FUNCTION_LOG_RETURN(STRING_LIST, result);
 }
 
-/***********************************************************************************************************************************
-Get the remote protocol client
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 ProtocolClient *
 protocolRemoteGet(ProtocolStorageType protocolStorageType, unsigned int hostId)
 {
@@ -347,8 +407,10 @@ protocolRemoteGet(ProtocolStorageType protocolStorageType, unsigned int hostId)
             ASSERT(cfgDefOptionIndexTotal(cfgDefOptPgPath) >= cfgDefOptionIndexTotal(cfgDefOptRepoPath));
 
             protocolHelper.clientRemoteSize = cfgDefOptionIndexTotal(cfgDefOptPgPath) + 1;
-            protocolHelper.clientRemote = (ProtocolHelperClient *)memNew(
-                protocolHelper.clientRemoteSize * sizeof(ProtocolHelperClient));
+            protocolHelper.clientRemote = memNew(protocolHelper.clientRemoteSize * sizeof(ProtocolHelperClient));
+
+            for (unsigned int clientIdx = 0; clientIdx < protocolHelper.clientRemoteSize; clientIdx++)
+                protocolHelper.clientRemote[clientIdx] = (ProtocolHelperClient){.exec = NULL};
         }
         MEM_CONTEXT_END();
     }
@@ -439,9 +501,7 @@ protocolRemoteFree(unsigned int hostId)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Send keepalives to all remotes
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 protocolKeepAlive(void)
 {
@@ -460,7 +520,7 @@ protocolKeepAlive(void)
 }
 
 /***********************************************************************************************************************************
-Getters
+Getters/Setters
 ***********************************************************************************************************************************/
 ProtocolStorageType
 protocolStorageTypeEnum(const String *type)
@@ -471,9 +531,9 @@ protocolStorageTypeEnum(const String *type)
 
     ASSERT(type != NULL);
 
-    if (strEq(type, PROTOCOL_STORAGE_TYPE_PG_STR))
+    if (strEq(type, PROTOCOL_REMOTE_TYPE_PG_STR))
         FUNCTION_TEST_RETURN(protocolStorageTypePg);
-    else if (strEq(type, PROTOCOL_STORAGE_TYPE_REPO_STR))
+    else if (strEq(type, PROTOCOL_REMOTE_TYPE_REPO_STR))
         FUNCTION_TEST_RETURN(protocolStorageTypeRepo);
 
     THROW_FMT(AssertError, "invalid protocol storage type '%s'", strPtr(type));
@@ -489,18 +549,16 @@ protocolStorageTypeStr(ProtocolStorageType type)
     switch (type)
     {
         case protocolStorageTypePg:
-            FUNCTION_TEST_RETURN(PROTOCOL_STORAGE_TYPE_PG_STR);
+            FUNCTION_TEST_RETURN(PROTOCOL_REMOTE_TYPE_PG_STR);
 
         case protocolStorageTypeRepo:
-            FUNCTION_TEST_RETURN(PROTOCOL_STORAGE_TYPE_REPO_STR);
+            FUNCTION_TEST_RETURN(PROTOCOL_REMOTE_TYPE_REPO_STR);
     }
 
     THROW_FMT(AssertError, "invalid protocol storage type %u", type);
 }
 
-/***********************************************************************************************************************************
-Free the protocol objects and shutdown processes
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 protocolFree(void)
 {
@@ -522,8 +580,7 @@ protocolFree(void)
                 protocolClientFree(protocolHelperClient->client);
                 execFree(protocolHelperClient->exec);
 
-                protocolHelperClient->client = NULL;
-                protocolHelperClient->exec = NULL;
+                *protocolHelperClient = (ProtocolHelperClient){.exec = NULL};
             }
         }
     }
