@@ -6,7 +6,7 @@ Storage Read Interface
 #include "common/debug.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "storage/read.intern.h"
 
 /***********************************************************************************************************************************
@@ -31,9 +31,7 @@ Macros for function logging
 #define FUNCTION_LOG_STORAGE_READ_INTERFACE_FORMAT(value, buffer, bufferSize)                                                      \
     objToLog(&value, "StorageReadInterface", buffer, bufferSize)
 
-/***********************************************************************************************************************************
-Create a new storage file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StorageRead *
 storageReadNew(void *driver, const StorageReadInterface *interface)
 {
@@ -60,24 +58,7 @@ storageReadNew(void *driver, const StorageReadInterface *interface)
     FUNCTION_LOG_RETURN(STORAGE_READ, this);
 }
 
-/***********************************************************************************************************************************
-Get file driver
-***********************************************************************************************************************************/
-void *
-storageRead(const StorageRead *this)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(STORAGE_READ, this);
-    FUNCTION_TEST_END();
-
-    ASSERT(this != NULL);
-
-    FUNCTION_TEST_RETURN(this->driver);
-}
-
-/***********************************************************************************************************************************
-Should a missing file be ignored?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 storageReadIgnoreMissing(const StorageRead *this)
 {
@@ -103,9 +84,7 @@ storageReadLimit(const StorageRead *this)
     FUNCTION_TEST_RETURN(this->interface->limit);
 }
 
-/***********************************************************************************************************************************
-Get io interface
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 IoRead *
 storageReadIo(const StorageRead *this)
 {
@@ -118,9 +97,7 @@ storageReadIo(const StorageRead *this)
     FUNCTION_TEST_RETURN(this->io);
 }
 
-/***********************************************************************************************************************************
-Get file name
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 storageReadName(const StorageRead *this)
 {
@@ -133,9 +110,7 @@ storageReadName(const StorageRead *this)
     FUNCTION_TEST_RETURN(this->interface->name);
 }
 
-/***********************************************************************************************************************************
-Get file type
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 storageReadType(const StorageRead *this)
 {
@@ -148,9 +123,7 @@ storageReadType(const StorageRead *this)
     FUNCTION_TEST_RETURN(this->interface->type);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 storageReadToLog(const StorageRead *this)
 {
