@@ -4,7 +4,6 @@ S3 Storage
 #include "build.auto.h"
 
 #include <string.h>
-#include <time.h>
 
 #include "common/crypto/hash.h"
 #include "common/encode.h"
@@ -13,8 +12,8 @@ S3 Storage
 #include "common/io/http/common.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
 #include "common/regExp.h"
+#include "common/type/object.h"
 #include "common/type/xml.h"
 #include "storage/s3/read.h"
 #include "storage/s3/storage.intern.h"
@@ -59,6 +58,7 @@ STRING_STATIC(S3_XML_TAG_CONTENTS_STR,                              "Contents");
 STRING_STATIC(S3_XML_TAG_DELETE_STR,                                "Delete");
 STRING_STATIC(S3_XML_TAG_ERROR_STR,                                 "Error");
 STRING_STATIC(S3_XML_TAG_KEY_STR,                                   "Key");
+STRING_STATIC(S3_XML_TAG_LAST_MODIFIED_STR,                         "LastModified");
 STRING_STATIC(S3_XML_TAG_MESSAGE_STR,                               "Message");
 STRING_STATIC(S3_XML_TAG_NEXT_CONTINUATION_TOKEN_STR,               "NextContinuationToken");
 STRING_STATIC(S3_XML_TAG_OBJECT_STR,                                "Object");
@@ -98,6 +98,7 @@ struct StorageS3
     const String *securityToken;                                    // Security token, if any
     size_t partSize;                                                // Part size for multi-part upload
     unsigned int deleteMax;                                         // Maximum objects that can be deleted in one request
+    StorageS3UriStyle uriStyle;                                     // Path or host style URIs
     const String *bucketEndpoint;                                   // Set to {bucket}.{endpoint}
     unsigned int port;                                              // Host port
 
@@ -258,6 +259,10 @@ storageS3Request(
     unsigned int retryRemaining = 2;
     bool done;
 
+    // When using path-style URIs the bucket name needs to be prepended
+    if (this->uriStyle == storageS3UriStylePath)
+        uri = strNewFmt("/%s%s", strPtr(this->bucket), strPtr(uri));
+
     do
     {
         done = true;
@@ -377,11 +382,11 @@ storageS3Request(
             }
             else
             {
-                // On success move the buffer to the calling context
+                // On success move the buffer to the prior context
                 result.httpClient = httpClient;
                 result.responseHeader = httpHeaderMove(
-                    httpHeaderDup(httpClientResponseHeader(httpClient), NULL), MEM_CONTEXT_OLD());
-                result.response = bufMove(response, MEM_CONTEXT_OLD());
+                    httpHeaderDup(httpClientResponseHeader(httpClient), NULL), memContextPrior());
+                result.response = bufMove(response, memContextPrior());
             }
 
         }
@@ -417,9 +422,6 @@ storageS3ListInternal(
     {
         const String *continuationToken = NULL;
 
-        // Prepare regexp if an expression was passed
-        RegExp *regExp = expression == NULL ? NULL : regExpNew(expression);
-
         // Build the base prefix by stripping off the initial /
         const String *basePrefix;
 
@@ -485,9 +487,8 @@ storageS3ListInternal(
                     // Strip off base prefix and final /
                     subPath = strSubN(subPath, strSize(basePrefix), strSize(subPath) - strSize(basePrefix) - 1);
 
-                    // Add to list after checking expression if present
-                    if (regExp == NULL || regExpMatch(regExp, subPath))
-                        callback(this, callbackData, subPath, storageTypePath, subPathNode);
+                    // Add to list
+                    callback(this, callbackData, subPath, storageTypePath, subPathNode);
                 }
 
                 // Get file list
@@ -503,15 +504,16 @@ storageS3ListInternal(
                     // Strip off the base prefix when present
                     file = strEmpty(basePrefix) ? file : strSub(file, strSize(basePrefix));
 
-                    // Add to list after checking expression if present
-                    if (regExp == NULL || regExpMatch(regExp, file))
-                        callback(this, callbackData, file, storageTypeFile, fileNode);
+                    // Add to list
+                    callback(this, callbackData, file, storageTypeFile, fileNode);
                 }
 
                 // Get the continuation token and store it in the outer temp context
-                memContextSwitch(MEM_CONTEXT_OLD());
-                continuationToken = xmlNodeContent(xmlNodeChild(xmlRoot, S3_XML_TAG_NEXT_CONTINUATION_TOKEN_STR, false));
-                memContextSwitch(MEM_CONTEXT_TEMP());
+                MEM_CONTEXT_PRIOR_BEGIN()
+                {
+                    continuationToken = xmlNodeContent(xmlNodeChild(xmlRoot, S3_XML_TAG_NEXT_CONTINUATION_TOKEN_STR, false));
+                }
+                MEM_CONTEXT_PRIOR_END();
             }
             MEM_CONTEXT_TEMP_END();
         }
@@ -522,58 +524,34 @@ storageS3ListInternal(
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/**********************************************************************************************************************************/
-static bool
-storageS3Exists(THIS_VOID, const String *file, StorageInterfaceExistsParam param)
-{
-    THIS(StorageS3);
-
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STORAGE_S3, this);
-        FUNCTION_LOG_PARAM(STRING, file);
-        (void)param;                                                // No parameters are used
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-    ASSERT(file != NULL);
-
-    bool result = false;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        result = httpClientResponseCodeOk(storageS3Request(this, HTTP_VERB_HEAD_STR, file, NULL, NULL, true, true).httpClient);
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    FUNCTION_LOG_RETURN(BOOL, result);
-}
-
 /**********************************************************************************************************************************/
 static StorageInfo
-storageS3Info(THIS_VOID, const String *file, StorageInterfaceInfoParam param)
+storageS3Info(THIS_VOID, const String *file, StorageInfoLevel level, StorageInterfaceInfoParam param)
 {
     THIS(StorageS3);
 
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_S3, this);
         FUNCTION_LOG_PARAM(STRING, file);
+        FUNCTION_LOG_PARAM(ENUM, level);
         (void)param;                                                // No parameters are used
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
     ASSERT(file != NULL);
 
-    StorageInfo result = {0};
-
     // Attempt to get file info
     StorageS3RequestResult httpResult = storageS3Request(this, HTTP_VERB_HEAD_STR, file, NULL, NULL, true, true);
 
-    // On success load info into a structure
-    if (httpClientResponseCodeOk(httpResult.httpClient))
+    // Does the file exist?
+    StorageInfo result = {.level = level, .exists = httpClientResponseCodeOk(httpResult.httpClient)};
+
+    // Add basic level info if requested and the file exists
+    if (result.level >= storageInfoLevelBasic && result.exists)
     {
-        result.exists = true;
         result.type = storageTypeFile;
         result.size = cvtZToUInt64(strPtr(httpHeaderGet(httpResult.responseHeader, HTTP_HEADER_CONTENT_LENGTH_STR)));
+        result.timeModified = httpLastModifiedToTime(httpHeaderGet(httpResult.responseHeader, HTTP_HEADER_LAST_MODIFIED_STR));
     }
 
     FUNCTION_LOG_RETURN(STORAGE_INFO, result);
@@ -582,10 +560,27 @@ storageS3Info(THIS_VOID, const String *file, StorageInterfaceInfoParam param)
 /**********************************************************************************************************************************/
 typedef struct StorageS3InfoListData
 {
+    StorageInfoLevel level;                                         // Level of info to set
     StorageInfoListCallback callback;                               // User-supplied callback function
     void *callbackData;                                             // User-supplied callback data
 } StorageS3InfoListData;
 
+// Helper to convert YYYY-MM-DDTHH:MM:SS.MSECZ format to time_t.  This format is very nearly ISO-8601 except for the inclusion of
+// milliseconds which are discarded here.
+static time_t
+storageS3CvtTime(const String *time)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(STRING, time);
+    FUNCTION_TEST_END();
+
+    FUNCTION_TEST_RETURN(
+        epochFromParts(
+            cvtZToInt(strPtr(strSubN(time, 0, 4))), cvtZToInt(strPtr(strSubN(time, 5, 2))),
+            cvtZToInt(strPtr(strSubN(time, 8, 2))), cvtZToInt(strPtr(strSubN(time, 11, 2))),
+            cvtZToInt(strPtr(strSubN(time, 14, 2))), cvtZToInt(strPtr(strSubN(time, 17, 2))), 0));
+}
+
 static void
 storageS3InfoListCallback(StorageS3 *this, void *callbackData, const String *name, StorageType type, const XmlNode *xml)
 {
@@ -606,11 +601,20 @@ storageS3InfoListCallback(StorageS3 *this, void *callbackData, const String *nam
 
     StorageInfo info =
     {
-        .type = type,
         .name = name,
-        .size = type == storageTypeFile ? cvtZToUInt64(strPtr(xmlNodeContent(xmlNodeChild(xml, S3_XML_TAG_SIZE_STR, true)))) : 0,
+        .level = data->level,
+        .exists = true,
     };
 
+    if (data->level >= storageInfoLevelBasic)
+    {
+        info.type = type;
+        info.size = type == storageTypeFile ?
+            cvtZToUInt64(strPtr(xmlNodeContent(xmlNodeChild(xml, S3_XML_TAG_SIZE_STR, true)))) : 0;
+        info.timeModified = type == storageTypeFile ?
+            storageS3CvtTime(xmlNodeContent(xmlNodeChild(xml, S3_XML_TAG_LAST_MODIFIED_STR, true))) : 0;
+    }
+
     data->callback(data->callbackData, &info);
 
     FUNCTION_TEST_RETURN_VOID();
@@ -618,16 +622,18 @@ storageS3InfoListCallback(StorageS3 *this, void *callbackData, const String *nam
 
 static bool
 storageS3InfoList(
-    THIS_VOID, const String *path, StorageInfoListCallback callback, void *callbackData, StorageInterfaceInfoListParam param)
+    THIS_VOID, const String *path, StorageInfoLevel level, StorageInfoListCallback callback, void *callbackData,
+    StorageInterfaceInfoListParam param)
 {
     THIS(StorageS3);
 
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_S3, this);
         FUNCTION_LOG_PARAM(STRING, path);
+        FUNCTION_LOG_PARAM(ENUM, level);
         FUNCTION_LOG_PARAM(FUNCTIONP, callback);
         FUNCTION_LOG_PARAM_P(VOID, callbackData);
-        (void)param;                                                // No parameters are used
+        FUNCTION_LOG_PARAM(STRING, param.expression);
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
@@ -636,65 +642,14 @@ storageS3InfoList(
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        StorageS3InfoListData data = {.callback = callback, .callbackData = callbackData};
-        storageS3ListInternal(this, path, false, false, storageS3InfoListCallback, &data);
+        StorageS3InfoListData data = {.level = level, .callback = callback, .callbackData = callbackData};
+        storageS3ListInternal(this, path, param.expression, false, storageS3InfoListCallback, &data);
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(BOOL, true);
 }
 
-/**********************************************************************************************************************************/
-static void
-storageS3ListCallback(StorageS3 *this, void *callbackData, const String *name, StorageType type, const XmlNode *xml)
-{
-    FUNCTION_TEST_BEGIN();
-        FUNCTION_TEST_PARAM(STORAGE_S3, this);
-        FUNCTION_TEST_PARAM_P(VOID, callbackData);
-        FUNCTION_TEST_PARAM(STRING, name);
-        FUNCTION_TEST_PARAM(ENUM, type);
-        FUNCTION_TEST_PARAM(XML_NODE, xml);
-    FUNCTION_TEST_END();
-
-    (void)this;
-    ASSERT(callbackData != NULL);
-    ASSERT(name != NULL);
-    (void)type;
-    (void)xml;
-
-    strLstAdd((StringList *)callbackData, name);
-
-    FUNCTION_TEST_RETURN_VOID();
-}
-
-static StringList *
-storageS3List(THIS_VOID, const String *path, StorageInterfaceListParam param)
-{
-    THIS(StorageS3);
-
-    FUNCTION_LOG_BEGIN(logLevelDebug);
-        FUNCTION_LOG_PARAM(STORAGE_S3, this);
-        FUNCTION_LOG_PARAM(STRING, path);
-        FUNCTION_LOG_PARAM(STRING, param.expression);
-    FUNCTION_LOG_END();
-
-    ASSERT(this != NULL);
-    ASSERT(path != NULL);
-
-    StringList *result = NULL;
-
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        result = strLstNew();
-
-        storageS3ListInternal(this, path, param.expression, false, storageS3ListCallback, result);
-        strLstMove(result, MEM_CONTEXT_OLD());
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    FUNCTION_LOG_RETURN(STRING_LIST, result);
-}
-
 /**********************************************************************************************************************************/
 static StorageRead *
 storageS3NewRead(THIS_VOID, const String *file, bool ignoreMissing, StorageInterfaceNewReadParam param)
@@ -803,12 +758,12 @@ storageS3PathRemoveCallback(StorageS3 *this, void *callbackData, const String *n
         // If there is something to delete then create the request
         if (data->xml == NULL)
         {
-            MemContext *memContextOld = memContextSwitch(data->memContext);
-
-            data->xml = xmlDocumentNew(S3_XML_TAG_DELETE_STR);
-            xmlNodeContentSet(xmlNodeAdd(xmlDocumentRoot(data->xml), S3_XML_TAG_QUIET_STR), TRUE_STR);
-
-            memContextSwitch(memContextOld);
+            MEM_CONTEXT_BEGIN(data->memContext)
+            {
+                data->xml = xmlDocumentNew(S3_XML_TAG_DELETE_STR);
+                xmlNodeContentSet(xmlNodeAdd(xmlDocumentRoot(data->xml), S3_XML_TAG_QUIET_STR), TRUE_STR);
+            }
+            MEM_CONTEXT_END();
         }
 
         // Add to delete list
@@ -880,15 +835,11 @@ storageS3Remove(THIS_VOID, const String *file, StorageInterfaceRemoveParam param
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-New object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 static const StorageInterface storageInterfaceS3 =
 {
-    .exists = storageS3Exists,
     .info = storageS3Info,
     .infoList = storageS3InfoList,
-    .list = storageS3List,
     .newRead = storageS3NewRead,
     .newWrite = storageS3NewWrite,
     .pathRemove = storageS3PathRemove,
@@ -898,9 +849,9 @@ static const StorageInterface storageInterfaceS3 =
 Storage *
 storageS3New(
     const String *path, bool write, StoragePathExpressionCallback pathExpressionFunction, const String *bucket,
-    const String *endPoint, const String *region, const String *accessKey, const String *secretAccessKey,
-    const String *securityToken, size_t partSize, unsigned int deleteMax, const String *host, unsigned int port, TimeMSec timeout,
-    bool verifyPeer, const String *caFile, const String *caPath)
+    const String *endPoint, StorageS3UriStyle uriStyle, const String *region, const String *accessKey,
+    const String *secretAccessKey, const String *securityToken, size_t partSize, unsigned int deleteMax, const String *host,
+    unsigned int port, TimeMSec timeout, bool verifyPeer, const String *caFile, const String *caPath)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, path);
@@ -908,6 +859,7 @@ storageS3New(
         FUNCTION_LOG_PARAM(FUNCTIONP, pathExpressionFunction);
         FUNCTION_LOG_PARAM(STRING, bucket);
         FUNCTION_LOG_PARAM(STRING, endPoint);
+        FUNCTION_LOG_PARAM(ENUM, uriStyle);
         FUNCTION_LOG_PARAM(STRING, region);
         FUNCTION_TEST_PARAM(STRING, accessKey);
         FUNCTION_TEST_PARAM(STRING, secretAccessKey);
@@ -933,21 +885,26 @@ storageS3New(
     MEM_CONTEXT_NEW_BEGIN("StorageS3")
     {
         StorageS3 *driver = memNew(sizeof(StorageS3));
-        driver->memContext = MEM_CONTEXT_NEW();
-        driver->interface = storageInterfaceS3;
 
-        driver->bucket = strDup(bucket);
-        driver->region = strDup(region);
-        driver->accessKey = strDup(accessKey);
-        driver->secretAccessKey = strDup(secretAccessKey);
-        driver->securityToken = strDup(securityToken);
-        driver->partSize = partSize;
-        driver->deleteMax = deleteMax;
-        driver->bucketEndpoint = strNewFmt("%s.%s", strPtr(bucket), strPtr(endPoint));
-        driver->port = port;
+        *driver = (StorageS3)
+        {
+            .memContext = MEM_CONTEXT_NEW(),
+            .interface = storageInterfaceS3,
+            .bucket = strDup(bucket),
+            .region = strDup(region),
+            .accessKey = strDup(accessKey),
+            .secretAccessKey = strDup(secretAccessKey),
+            .securityToken = strDup(securityToken),
+            .partSize = partSize,
+            .deleteMax = deleteMax,
+            .uriStyle = uriStyle,
+            .bucketEndpoint = uriStyle == storageS3UriStyleHost ?
+                strNewFmt("%s.%s", strPtr(bucket), strPtr(endPoint)) : strDup(endPoint),
+            .port = port,
 
-        // Force the signing key to be generated on the first run
-        driver->signingKeyDate = YYYYMMDD_STR;
+            // Force the signing key to be generated on the first run
+            .signingKeyDate = YYYYMMDD_STR,
+        };
 
         // Create the http client cache used to service requests
         driver->httpClientCache = httpClientCacheNew(
