@@ -11,7 +11,7 @@ Storage Interface
 #include "common/type/list.h"
 #include "common/log.h"
 #include "common/memContext.h"
-#include "common/object.h"
+#include "common/type/object.h"
 #include "common/regExp.h"
 #include "common/wait.h"
 #include "storage/storage.intern.h"
@@ -35,9 +35,7 @@ struct Storage
 
 OBJECT_DEFINE_FREE(STORAGE);
 
-/***********************************************************************************************************************************
-New storage object
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Storage *
 storageNew(
     const String *type, const String *path, mode_t modeFile, mode_t modePath, bool write,
@@ -57,9 +55,7 @@ storageNew(
     ASSERT(type != NULL);
     ASSERT(strSize(path) >= 1 && strPtr(path)[0] == '/');
     ASSERT(driver != NULL);
-    ASSERT(interface.exists != NULL);
     ASSERT(interface.info != NULL);
-    ASSERT(interface.list != NULL);
     ASSERT(interface.infoList != NULL);
     ASSERT(interface.newRead != NULL);
     ASSERT(interface.newWrite != NULL);
@@ -93,9 +89,7 @@ storageNew(
     FUNCTION_LOG_RETURN(STORAGE, this);
 }
 
-/***********************************************************************************************************************************
-Copy a file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 storageCopy(StorageRead *source, StorageWrite *destination)
 {
@@ -141,9 +135,7 @@ storageCopy(StorageRead *source, StorageWrite *destination)
     FUNCTION_LOG_RETURN(BOOL, result);
 }
 
-/***********************************************************************************************************************************
-Does a file exist? This function is only for files, not paths.
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 storageExists(const Storage *this, const String *pathExp, StorageExistsParam param)
 {
@@ -159,28 +151,27 @@ storageExists(const Storage *this, const String *pathExp, StorageExistsParam par
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Build the path to the file
-        String *path = storagePathP(this, pathExp);
-
-        // Create Wait object of timeout > 0
-        Wait *wait = param.timeout != 0 ? waitNew(param.timeout) : NULL;
+        Wait *wait = waitNew(param.timeout);
 
         // Loop until file exists or timeout
         do
         {
-            // Call driver function
-            result = storageInterfaceExistsP(this->driver, path);
+            // storageInfoLevelBasic is required here because storageInfoLevelExists will not return the type and this function
+            // specifically wants to test existence of a *file*, not just the existence of anything with the specified name.
+            StorageInfo info = storageInfoP(
+                this, pathExp, .level = storageInfoLevelBasic, .ignoreMissing = true, .followLink = true);
+
+            // Only exists if it is a file
+            result = info.exists && info.type == storageTypeFile;
         }
-        while (!result && wait != NULL && waitMore(wait));
+        while (!result && waitMore(wait));
     }
     MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN(BOOL, result);
 }
 
-/***********************************************************************************************************************************
-Read from storage into a buffer
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 Buffer *
 storageGet(StorageRead *file, StorageGetParam param)
 {
@@ -240,15 +231,14 @@ storageGet(StorageRead *file, StorageGetParam param)
     FUNCTION_LOG_RETURN(BUFFER, result);
 }
 
-/***********************************************************************************************************************************
-File/path info
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StorageInfo
 storageInfo(const Storage *this, const String *fileExp, StorageInfoParam param)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STORAGE, this);
         FUNCTION_LOG_PARAM(STRING, fileExp);
+        FUNCTION_LOG_PARAM(ENUM, param.level);
         FUNCTION_LOG_PARAM(BOOL, param.ignoreMissing);
         FUNCTION_LOG_PARAM(BOOL, param.followLink);
         FUNCTION_LOG_PARAM(BOOL, param.noPathEnforce);
@@ -265,7 +255,11 @@ storageInfo(const Storage *this, const String *fileExp, StorageInfoParam param)
         String *file = storagePathP(this, fileExp, .noEnforce = param.noPathEnforce);
 
         // Call driver function
-        result = storageInterfaceInfoP(this->driver, file, .followLink = param.followLink);
+        if (param.level == storageInfoLevelDefault)
+            param.level = storageFeature(this, storageFeatureInfoDetail) ? storageInfoLevelDetail : storageInfoLevelBasic;
+
+        result = storageInterfaceInfoP(
+            this->driver, file, param.level, .followLink = param.followLink);
 
         // Error if the file missing and not ignoring
         if (!result.exists && !param.ignoreMissing)
@@ -285,9 +279,7 @@ storageInfo(const Storage *this, const String *fileExp, StorageInfoParam param)
     FUNCTION_LOG_RETURN(STORAGE_INFO, result);
 }
 
-/***********************************************************************************************************************************
-Info for all files/paths in a path
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 typedef struct StorageInfoListSortData
 {
     MemContext *memContext;                                         // Mem context to use for allocating data in this struct
@@ -323,11 +315,14 @@ storageInfoListSortCallback(void *data, const StorageInfo *info)
 
 static bool
 storageInfoListSort(
-    const Storage *this, const String *path, SortOrder sortOrder, StorageInfoListCallback callback, void *callbackData)
+    const Storage *this, const String *path, StorageInfoLevel level, const String *expression, SortOrder sortOrder,
+    StorageInfoListCallback callback, void *callbackData)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE, this);
         FUNCTION_LOG_PARAM(STRING, path);
+        FUNCTION_LOG_PARAM(ENUM, level);
+        FUNCTION_LOG_PARAM(STRING, expression);
         FUNCTION_LOG_PARAM(ENUM, sortOrder);
         FUNCTION_LOG_PARAM(FUNCTIONP, callback);
         FUNCTION_LOG_PARAM_P(VOID, callbackData);
@@ -343,7 +338,7 @@ storageInfoListSort(
         // If no sorting then use the callback directly
         if (sortOrder == sortOrderNone)
         {
-            result = storageInterfaceInfoListP(this->driver, path, callback, callbackData);
+            result = storageInterfaceInfoListP(this->driver, path, level, callback, callbackData, .expression = expression);
         }
         // Else sort the info before sending it to the callback
         else
@@ -355,7 +350,8 @@ storageInfoListSort(
                 .infoList = lstNewP(sizeof(StorageInfo), .comparator = lstComparatorStr),
             };
 
-            result = storageInterfaceInfoListP(this->driver, path, storageInfoListSortCallback, &data);
+            result = storageInterfaceInfoListP(
+                this->driver, path, level, storageInfoListSortCallback, &data, .expression = expression);
             lstSort(data.infoList, sortOrder);
 
             MEM_CONTEXT_TEMP_RESET_BEGIN()
@@ -382,7 +378,8 @@ typedef struct StorageInfoListData
     const Storage *storage;                                         // Storage object;
     StorageInfoListCallback callbackFunction;                       // Original callback function
     void *callbackData;                                             // Original callback data
-    RegExp *expression;                                             // Filter for names
+    const String *expression;                                       // Filter for names
+    RegExp *regExp;                                                 // Compiled filter for names
     bool recurse;                                                   // Should we recurse?
     SortOrder sortOrder;                                            // Sort order
     const String *path;                                             // Top-level path for info
@@ -416,7 +413,7 @@ storageInfoListCallback(void *data, const StorageInfo *info)
         infoUpdate.name = strNewFmt("%s/%s", strPtr(listData->subPath), strPtr(infoUpdate.name));
 
     // Only continue if there is no expression or the expression matches
-    if (listData->expression == NULL || regExpMatch(listData->expression, infoUpdate.name))
+    if (listData->expression == NULL || regExpMatch(listData->regExp, infoUpdate.name))
     {
         if (listData->sortOrder != sortOrderDesc)
             listData->callbackFunction(listData->callbackData, &infoUpdate);
@@ -428,8 +425,8 @@ storageInfoListCallback(void *data, const StorageInfo *info)
             data.subPath = infoUpdate.name;
 
             storageInfoListSort(
-                data.storage, strNewFmt("%s/%s", strPtr(data.path), strPtr(data.subPath)), data.sortOrder, storageInfoListCallback,
-                &data);
+                data.storage, strNewFmt("%s/%s", strPtr(data.path), strPtr(data.subPath)), infoUpdate.level, data.expression,
+                data.sortOrder, storageInfoListCallback, &data);
         }
 
         if (listData->sortOrder == sortOrderDesc)
@@ -448,6 +445,7 @@ storageInfoList(
         FUNCTION_LOG_PARAM(STRING, pathExp);
         FUNCTION_LOG_PARAM(FUNCTIONP, callback);
         FUNCTION_LOG_PARAM_P(VOID, callbackData);
+        FUNCTION_LOG_PARAM(ENUM, param.level);
         FUNCTION_LOG_PARAM(BOOL, param.errorOnMissing);
         FUNCTION_LOG_PARAM(ENUM, param.sortOrder);
         FUNCTION_LOG_PARAM(STRING, param.expression);
@@ -463,6 +461,10 @@ storageInfoList(
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
+        // Info level
+        if (param.level == storageInfoLevelDefault)
+            param.level = storageFeature(this, storageFeatureInfoDetail) ? storageInfoLevelDetail : storageInfoLevelBasic;
+
         // Build the path
         String *path = storagePathP(this, pathExp);
 
@@ -474,18 +476,20 @@ storageInfoList(
                 .storage = this,
                 .callbackFunction = callback,
                 .callbackData = callbackData,
+                .expression = param.expression,
                 .sortOrder = param.sortOrder,
                 .recurse = param.recurse,
                 .path = path,
             };
 
-            if (param.expression != NULL)
-                data.expression = regExpNew(param.expression);
+            if (data.expression != NULL)
+                data.regExp = regExpNew(param.expression);
 
-            result = storageInfoListSort(this, path, param.sortOrder, storageInfoListCallback, &data);
+            result = storageInfoListSort(
+                this, path, param.level, param.expression, param.sortOrder, storageInfoListCallback, &data);
         }
         else
-            result = storageInfoListSort(this, path, param.sortOrder, callback, callbackData);
+            result = storageInfoListSort(this, path, param.level, NULL, param.sortOrder, callback, callbackData);
 
         if (!result && param.errorOnMissing)
             THROW_FMT(PathMissingError, STORAGE_ERROR_LIST_INFO_MISSING, strPtr(path));
@@ -495,9 +499,27 @@ storageInfoList(
     FUNCTION_LOG_RETURN(BOOL, result);
 }
 
-/***********************************************************************************************************************************
-Get a list of files from a directory
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
+static void
+storageListCallback(void *data, const StorageInfo *info)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_LOG_PARAM_P(VOID, data);
+        FUNCTION_LOG_PARAM(STORAGE_INFO, info);
+    FUNCTION_TEST_END();
+
+    // Skip . path
+    if (strEq(info->name, DOT_STR))
+    {
+        FUNCTION_TEST_RETURN_VOID();
+        return;
+    }
+
+    strLstAdd((StringList *)data, info->name);
+
+    FUNCTION_TEST_RETURN_VOID();
+}
+
 StringList *
 storageList(const Storage *this, const String *pathExp, StorageListParam param)
 {
@@ -517,23 +539,16 @@ storageList(const Storage *this, const String *pathExp, StorageListParam param)
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Build the path
-        String *path = storagePathP(this, pathExp);
+        result = strLstNew();
 
-        // Get the list
-        result = storageInterfaceListP(this->driver, path, .expression = param.expression);
-
-        // If the path does not exist
-        if (result == NULL)
+        // Build an empty list if the directory does not exist by default.  This makes the logic in calling functions simpler when
+        // the caller doesn't care if the path is missing.
+        if (!storageInfoListP(
+                this, pathExp, storageListCallback, result, .level = storageInfoLevelExists, .errorOnMissing = param.errorOnMissing,
+                .expression = param.expression))
         {
-            // Error if requested
-            if (param.errorOnMissing)
-                THROW_FMT(PathMissingError, STORAGE_ERROR_LIST_MISSING, strPtr(path));
-
-            // Build an empty list if the directory does not exist by default.  This makes the logic in calling functions simpler
-            // when they don't care if the path is missing.
-            if (!param.nullOnMissing)
-                result = strLstNew();
+            if (param.nullOnMissing)
+                result = NULL;
         }
 
         // Move list up to the old context
@@ -544,9 +559,7 @@ storageList(const Storage *this, const String *pathExp, StorageListParam param)
     FUNCTION_LOG_RETURN(STRING_LIST, result);
 }
 
-/***********************************************************************************************************************************
-Move a file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 storageMove(const Storage *this, StorageRead *source, StorageWrite *destination)
 {
@@ -586,9 +599,7 @@ storageMove(const Storage *this, StorageRead *source, StorageWrite *destination)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Open a file for reading
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StorageRead *
 storageNewRead(const Storage *this, const String *fileExp, StorageNewReadParam param)
 {
@@ -619,9 +630,7 @@ storageNewRead(const Storage *this, const String *fileExp, StorageNewReadParam p
     FUNCTION_LOG_RETURN(STORAGE_READ, result);
 }
 
-/***********************************************************************************************************************************
-Open a file for writing
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StorageWrite *
 storageNewWrite(const Storage *this, const String *fileExp, StorageNewWriteParam param)
 {
@@ -660,9 +669,7 @@ storageNewWrite(const Storage *this, const String *fileExp, StorageNewWriteParam
     FUNCTION_LOG_RETURN(STORAGE_WRITE, result);
 }
 
-/***********************************************************************************************************************************
-Get the absolute path in the storage
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 storagePath(const Storage *this, const String *pathExp, StoragePathParam param)
 {
@@ -763,9 +770,7 @@ storagePath(const Storage *this, const String *pathExp, StoragePathParam param)
     FUNCTION_TEST_RETURN(result);
 }
 
-/***********************************************************************************************************************************
-Create a path
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 storagePathCreate(const Storage *this, const String *pathExp, StoragePathCreateParam param)
 {
@@ -795,9 +800,7 @@ storagePathCreate(const Storage *this, const String *pathExp, StoragePathCreateP
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Does a path exist?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 storagePathExists(const Storage *this, const String *pathExp)
 {
@@ -807,22 +810,16 @@ storagePathExists(const Storage *this, const String *pathExp)
     FUNCTION_LOG_END();
 
     ASSERT(this != NULL);
-    ASSERT(this->interface.pathExists != NULL);
+    ASSERT(storageFeature(this, storageFeaturePath));
 
-    bool result = false;
+    // storageInfoLevelBasic is required here because storageInfoLevelExists will not return the type and this function specifically
+    // wants to test existence of a *path*, not just the existence of anything with the specified name.
+    StorageInfo info = storageInfoP(this, pathExp, .level = storageInfoLevelBasic, .ignoreMissing = true, .followLink = true);
 
-    MEM_CONTEXT_TEMP_BEGIN()
-    {
-        result = storageInterfacePathExistsP(this->driver, storagePathP(this, pathExp));
-    }
-    MEM_CONTEXT_TEMP_END();
-
-    FUNCTION_LOG_RETURN(BOOL, result);
+    FUNCTION_LOG_RETURN(BOOL, info.exists && info.type == storageTypePath);
 }
 
-/***********************************************************************************************************************************
-Remove a path
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 storagePathRemove(const Storage *this, const String *pathExp, StoragePathRemoveParam param)
 {
@@ -854,9 +851,7 @@ storagePathRemove(const Storage *this, const String *pathExp, StoragePathRemoveP
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Sync a path
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void storagePathSync(const Storage *this, const String *pathExp)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -880,9 +875,7 @@ void storagePathSync(const Storage *this, const String *pathExp)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Write a buffer to storage
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 storagePut(StorageWrite *file, const Buffer *buffer)
 {
@@ -900,9 +893,7 @@ storagePut(StorageWrite *file, const Buffer *buffer)
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Remove a file
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void
 storageRemove(const Storage *this, const String *fileExp, StorageRemoveParam param)
 {
@@ -928,9 +919,7 @@ storageRemove(const Storage *this, const String *fileExp, StorageRemoveParam par
     FUNCTION_LOG_RETURN_VOID();
 }
 
-/***********************************************************************************************************************************
-Get the storage driver
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 void *
 storageDriver(const Storage *this)
 {
@@ -943,9 +932,7 @@ storageDriver(const Storage *this)
     FUNCTION_TEST_RETURN(this->driver);
 }
 
-/***********************************************************************************************************************************
-Is the feature supported by this storage?
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 bool
 storageFeature(const Storage *this, StorageFeature feature)
 {
@@ -959,9 +946,7 @@ storageFeature(const Storage *this, StorageFeature feature)
     FUNCTION_TEST_RETURN(this->interface.feature >> feature & 1);
 }
 
-/***********************************************************************************************************************************
-Get the storage interface
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 StorageInterface
 storageInterface(const Storage *this)
 {
@@ -974,9 +959,7 @@ storageInterface(const Storage *this)
     FUNCTION_TEST_RETURN(this->interface);
 }
 
-/***********************************************************************************************************************************
-Get the storage type (posix, cifs, etc.)
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 const String *
 storageType(const Storage *this)
 {
@@ -989,9 +972,7 @@ storageType(const Storage *this)
     FUNCTION_TEST_RETURN(this->type);
 }
 
-/***********************************************************************************************************************************
-Render as string for logging
-***********************************************************************************************************************************/
+/**********************************************************************************************************************************/
 String *
 storageToLog(const Storage *this)
 {
