@@ -13,31 +13,35 @@ use Carp qw(confess);
 
 use File::Basename qw(dirname);
 
-use pgBackRest::Archive::Info;
-use pgBackRest::Backup::Info;
-use pgBackRest::Db;
-use pgBackRest::DbVersion;
-use pgBackRest::Common::Exception;
-use pgBackRest::Common::Ini;
-use pgBackRest::Common::Log;
-use pgBackRest::Common::Wait;
-use pgBackRest::Config::Config;
-use pgBackRest::InfoCommon;
-use pgBackRest::Manifest;
-use pgBackRest::Protocol::Storage::Helper;
-use pgBackRest::Version;
+use pgBackRestDoc::Common::Exception;
+use pgBackRestDoc::Common::Ini;
+use pgBackRestDoc::Common::Log;
+use pgBackRestDoc::ProjectInfo;
 
 use pgBackRestTest::Common::ContainerTest;
+use pgBackRestTest::Common::DbVersion;
 use pgBackRestTest::Common::ExecuteTest;
 use pgBackRestTest::Common::FileTest;
 use pgBackRestTest::Common::RunTest;
 use pgBackRestTest::Common::VmTest;
+use pgBackRestTest::Common::Storage;
+use pgBackRestTest::Common::StoragePosix;
+use pgBackRestTest::Common::StorageRepo;
+use pgBackRestTest::Common::Wait;
+use pgBackRestTest::Env::ArchiveInfo;
+use pgBackRestTest::Env::BackupInfo;
+use pgBackRestTest::Env::InfoCommon;
 use pgBackRestTest::Env::Host::HostBaseTest;
 use pgBackRestTest::Env::Host::HostBackupTest;
 use pgBackRestTest::Env::Host::HostDbTest;
+use pgBackRestTest::Env::Host::HostDbTest;
 use pgBackRestTest::Env::HostEnvTest;
-use pgBackRestTest::Common::Storage;
-use pgBackRestTest::Common::StoragePosix;
+use pgBackRestTest::Env::Manifest;
+
+####################################################################################################################################
+# Backup advisory lock
+####################################################################################################################################
+use constant DB_BACKUP_ADVISORY_LOCK                                => '12340078987004321';
 
 ####################################################################################################################################
 # run
@@ -46,6 +50,9 @@ sub run
 {
     my $self = shift;
 
+    # Should the test use lz4 compression?
+    my $bLz4Compress = true;
+
     foreach my $bS3 (false, true)
     {
     foreach my $bHostBackup ($bS3 ? (true) : (false, true))
@@ -57,15 +64,21 @@ sub run
     foreach my $strBackupDestination (
         $bS3 || $bHostBackup ? (HOST_BACKUP) : $bHostStandby ? (HOST_DB_MASTER, HOST_DB_STANDBY) : (HOST_DB_MASTER))
     {
-        my $bCompress = $bHostBackup && !$bHostStandby;
-        my $bRepoEncrypt = ($bCompress && !$bS3) ? true : false;
+        my $strCompressType = $bHostBackup && !$bHostStandby ? (vmWithLz4($self->vm()) && $bLz4Compress ? LZ4 : GZ) : NONE;
+        my $bRepoEncrypt = ($strCompressType ne NONE && !$bS3) ? true : false;
+
+        # If compression was used then switch it for the next test that uses compression
+        if ($strCompressType ne NONE)
+        {
+            $bLz4Compress = !$bLz4Compress;
+        }
 
         # Increment the run, log, and decide whether this unit test should be run
         my $hyVm = vmGet();
         my $strDbVersionMostRecent = ${$hyVm->{$self->vm()}{&VM_DB_TEST}}[-1];
 
         next if (!$self->begin(
-            "bkp ${bHostBackup}, sby ${bHostStandby}, dst ${strBackupDestination}, cmp ${bCompress}, s3 ${bS3}, " .
+            "bkp ${bHostBackup}, sby ${bHostStandby}, dst ${strBackupDestination}, cmp ${strCompressType}, s3 ${bS3}, " .
                 "enc ${bRepoEncrypt}",
             # Use the most recent db version on the expect vm for expect testing
             $self->vm() eq VM_EXPECT && $self->pgVersion() eq $strDbVersionMostRecent));
@@ -95,7 +108,7 @@ sub run
         my ($oHostDbMaster, $oHostDbStandby, $oHostBackup, $oHostS3) = $self->setup(
             false, $self->expect(),
             {bHostBackup => $bHostBackup, bStandby => $bHostStandby, strBackupDestination => $strBackupDestination,
-             bCompress => $bCompress, bArchiveAsync => false, bS3 => $bS3, bRepoEncrypt => $bRepoEncrypt});
+             strCompressType => $strCompressType, bArchiveAsync => false, bS3 => $bS3, bRepoEncrypt => $bRepoEncrypt});
 
         # Only perform extra tests on certain runs to save time
         my $bTestLocal = $self->runCurrent() == 1;
@@ -106,8 +119,8 @@ sub run
         # without slowing down the other tests too much.
         if ($bS3)
         {
-            $oHostBackup->configUpdate({&CFGDEF_SECTION_GLOBAL => {cfgOptionName(CFGOPT_PROCESS_MAX) => 2}});
-            $oHostDbMaster->configUpdate({&CFGDEF_SECTION_GLOBAL => {cfgOptionName(CFGOPT_PROCESS_MAX) => 2}});
+            $oHostBackup->configUpdate({&CFGDEF_SECTION_GLOBAL => {'process-max' => 2}});
+            $oHostDbMaster->configUpdate({&CFGDEF_SECTION_GLOBAL => {'process-max' => 2}});
         }
 
         $oHostDbMaster->clusterCreate();
@@ -117,10 +130,10 @@ sub run
 
         # Get passphrase to access the Manifest file from backup.info - returns undefined if repo not encrypted
         my $strCipherPass =
-            (new pgBackRest::Backup::Info(storageRepo()->pathGet(STORAGE_REPO_BACKUP)))->cipherPassSub();
+            (new pgBackRestTest::Env::BackupInfo($oHostBackup->repoBackupPath()))->cipherPassSub();
 
         # Create a manifest with the pg version to get version-specific paths
-        my $oManifest = new pgBackRest::Manifest(BOGUS, {bLoad => false, strDbVersion => $self->pgVersion(),
+        my $oManifest = new pgBackRestTest::Env::Manifest(BOGUS, {bLoad => false, strDbVersion => $self->pgVersion(),
             iDbCatalogVersion => $self->dbCatalogVersion($self->pgVersion()),
             strCipherPass => $strCipherPass, strCipherPassSub => $bRepoEncrypt ? ENCRYPTION_KEY_BACKUPSET : undef});
 
@@ -152,13 +165,13 @@ sub run
             my $strComment = undef;
 
             # Archive and backup info file names
-            my $strArchiveInfoFile = STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE;
-            my $strArchiveInfoCopyFile = STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE . INI_COPY_EXT;
+            my $strArchiveInfoFile = $oHostBackup->repoArchivePath(ARCHIVE_INFO_FILE);
+            my $strArchiveInfoCopyFile = $oHostBackup->repoArchivePath(ARCHIVE_INFO_FILE . INI_COPY_EXT);
             my $strArchiveInfoOldFile = "${strArchiveInfoFile}.old";
             my $strArchiveInfoCopyOldFile = "${strArchiveInfoCopyFile}.old";
 
-            my $strBackupInfoFile = STORAGE_REPO_BACKUP . qw{/} . FILE_BACKUP_INFO;
-            my $strBackupInfoCopyFile = STORAGE_REPO_BACKUP . qw{/} . FILE_BACKUP_INFO . INI_COPY_EXT;
+            my $strBackupInfoFile = $oHostBackup->repoBackupPath(FILE_BACKUP_INFO);
+            my $strBackupInfoCopyFile = $oHostBackup->repoBackupPath(FILE_BACKUP_INFO . INI_COPY_EXT);
             my $strBackupInfoOldFile = "${strBackupInfoFile}.old";
             my $strBackupInfoCopyOldFile = "${strBackupInfoCopyFile}.old";
 
@@ -227,7 +240,7 @@ sub run
 
             # load the archive info file and munge it for testing by breaking the database version
             $oHostBackup->infoMunge(
-                storageRepo()->pathGet(STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE),
+                $oHostBackup->repoArchivePath(ARCHIVE_INFO_FILE),
                 {&INFO_ARCHIVE_SECTION_DB => {&INFO_ARCHIVE_KEY_DB_VERSION => '8.0'},
                  &INFO_ARCHIVE_SECTION_DB_HISTORY => {1 => {&INFO_ARCHIVE_KEY_DB_VERSION => '8.0'}}});
 
@@ -240,7 +253,7 @@ sub run
             }
 
             # Restore the file to its original condition
-            $oHostBackup->infoRestore(storageRepo()->pathGet(STORAGE_REPO_ARCHIVE . qw{/} . ARCHIVE_INFO_FILE));
+            $oHostBackup->infoRestore($oHostBackup->repoArchivePath(ARCHIVE_INFO_FILE));
 
             # Check archive_timeout error when WAL segment is not found
             $strComment = 'fail on archive timeout';
@@ -263,7 +276,7 @@ sub run
 
             # Load the backup.info file and munge it for testing by breaking the database version and system id
             $oHostBackup->infoMunge(
-                storageRepo()->pathGet(STORAGE_REPO_BACKUP . qw{/} . FILE_BACKUP_INFO),
+                $oHostBackup->repoBackupPath(FILE_BACKUP_INFO),
                 {&INFO_BACKUP_SECTION_DB =>
                     {&INFO_BACKUP_KEY_DB_VERSION => '8.0', &INFO_BACKUP_KEY_SYSTEM_ID => 6999999999999999999},
                 &INFO_BACKUP_SECTION_DB_HISTORY =>
@@ -279,7 +292,7 @@ sub run
             }
 
             # Restore the file to its original condition
-            $oHostBackup->infoRestore(storageRepo()->pathGet(STORAGE_REPO_BACKUP . qw{/} . FILE_BACKUP_INFO));
+            $oHostBackup->infoRestore($oHostBackup->repoBackupPath(FILE_BACKUP_INFO));
 
             # ??? Removed temporarily until manifest build can be brought back into the check command
             # Create a directory in pg_data location that is only readable by root to ensure manifest->build is called by check
@@ -319,7 +332,7 @@ sub run
                 'fail on backup info file missing from non-empty dir', {iExpectedExitStatus => ERROR_PATH_NOT_EMPTY});
 
             # Change the database version by copying a new pg_control file to a new pg-path to use for db mismatch test
-            storageDb()->pathCreate(
+            storageTest()->pathCreate(
                 $oHostDbMaster->dbPath() . '/testbase/' . DB_PATH_GLOBAL,
                 {strMode => '0700', bIgnoreExists => true, bCreateParent => true});
             $self->controlGenerate(
@@ -327,22 +340,20 @@ sub run
 
             # Run stanza-create online to confirm proper handling of configValidation error against new pg-path
             $oHostBackup->stanzaCreate('fail on database mismatch with directory',
-                {strOptionalParam => ' --' . cfgOptionName(CFGOPT_PG_PATH) . '=' . $oHostDbMaster->dbPath() .
-                '/testbase/', iExpectedExitStatus => ERROR_DB_MISMATCH});
+                {strOptionalParam => ' --pg1-path=' . $oHostDbMaster->dbPath() . '/testbase/',
+                    iExpectedExitStatus => ERROR_DB_MISMATCH});
 
             # Remove the directories to be able to create the stanza
-            forceStorageRemove(storageRepo(), STORAGE_REPO_BACKUP, {bRecurse => true});
-            forceStorageRemove(storageRepo(), STORAGE_REPO_ARCHIVE, {bRecurse => true});
+            forceStorageRemove(storageRepo(), $oHostBackup->repoBackupPath(), {bRecurse => true});
+            forceStorageRemove(storageRepo(), $oHostBackup->repoArchivePath(), {bRecurse => true});
 
             # Stanza Upgrade - tests configValidate code - all other tests in synthetic integration tests
             #-----------------------------------------------------------------------------------------------------------------------
             # Run stanza-create offline to create files needing to be upgraded (using new pg-path)
             $oHostBackup->stanzaCreate('successfully create stanza files to be upgraded',
-                {strOptionalParam =>
-                    ' --' . cfgOptionName(CFGOPT_PG_PATH) . '=' . $oHostDbMaster->dbPath() .
-                    '/testbase/ --no-' .  cfgOptionName(CFGOPT_ONLINE) . ' --' . cfgOptionName(CFGOPT_FORCE)});
-            my $oArchiveInfo = new pgBackRest::Archive::Info(storageRepo()->pathGet('archive/' . $self->stanza()));
-            my $oBackupInfo = new pgBackRest::Backup::Info(storageRepo()->pathGet('backup/' . $self->stanza()));
+                {strOptionalParam => ' --pg1-path=' . $oHostDbMaster->dbPath() . '/testbase/ --no-online --force'});
+            my $oArchiveInfo = new pgBackRestTest::Env::ArchiveInfo($oHostBackup->repoArchivePath());
+            my $oBackupInfo = new pgBackRestTest::Env::BackupInfo($oHostBackup->repoBackupPath());
 
             # Read info files to confirm the files were created with a different database version
             if ($self->pgVersion() eq PG_VERSION_94)
@@ -364,8 +375,8 @@ sub run
             $oHostBackup->stanzaUpgrade('upgrade stanza files online');
 
             # Reread the info files and confirm the result
-            $oArchiveInfo = new pgBackRest::Archive::Info(storageRepo()->pathGet('archive/' . $self->stanza()));
-            $oBackupInfo = new pgBackRest::Backup::Info(storageRepo()->pathGet('backup/' . $self->stanza()));
+            $oArchiveInfo = new pgBackRestTest::Env::ArchiveInfo($oHostBackup->repoArchivePath());
+            $oBackupInfo = new pgBackRestTest::Env::BackupInfo($oHostBackup->repoBackupPath());
             $self->testResult(sub {$oArchiveInfo->test(INFO_ARCHIVE_SECTION_DB, INFO_ARCHIVE_KEY_DB_VERSION, undef,
                 $self->pgVersion())}, true, 'archive upgrade online corrects db');
             $self->testResult(sub {$oBackupInfo->test(INFO_BACKUP_SECTION_DB, INFO_BACKUP_KEY_DB_VERSION, undef,
@@ -404,14 +415,14 @@ sub run
 
         my $strFullBackup = $oHostBackup->backup(
             CFGOPTVAL_BACKUP_TYPE_FULL, 'update during backup',
-            {strOptionalParam => ' --' . cfgOptionName(CFGOPT_BUFFER_SIZE) . '=16384'});
+            {strOptionalParam => ' --buffer-size=16384'});
 
         # Enabled async archiving
-        $oHostBackup->configUpdate({&CFGDEF_SECTION_GLOBAL => {cfgOptionName(CFGOPT_ARCHIVE_ASYNC) => 'y'}});
+        $oHostBackup->configUpdate({&CFGDEF_SECTION_GLOBAL => {'archive-async' => 'y'}});
 
         # Kick out a bunch of archive logs to exercise async archiving.  Only do this when compressed and remote to slow it
         # down enough to make it evident that the async process is working.
-        if ($bTestExtra && $bCompress && $strBackupDestination eq HOST_BACKUP)
+        if ($bTestExtra && $strCompressType ne NONE && $strBackupDestination eq HOST_BACKUP)
         {
             &log(INFO, '    multiple wal switches to exercise async archiving');
             $oHostDbMaster->sqlExecute("create table wal_activity (id int)");
@@ -439,7 +450,7 @@ sub run
             }
 
             $oHostDbStandby->restore(
-                'restore backup on replica', cfgDefOptionDefault(CFGCMD_RESTORE, CFGOPT_SET),
+                'restore backup on replica', 'latest',
                 {rhRemapHash => \%oRemapHash, strType => CFGOPTVAL_RESTORE_TYPE_STANDBY,
                     strOptionalParam =>
                         ' --recovery-option="primary_conninfo=host=' . HOST_DB_MASTER .
@@ -465,19 +476,13 @@ sub run
                 {
                     my $strStandbyBackup = $oHostBackup->backup(
                         CFGOPTVAL_BACKUP_TYPE_FULL, 'backup from standby, failure to reach master',
-                        {bStandby => true,
-                         iExpectedExitStatus => ERROR_DB_CONNECT,
-                         strOptionalParam => '--' .
-                         cfgOptionName(cfgOptionIdFromIndex(CFGOPT_PG_HOST, cfgOptionIndexTotal(CFGOPT_PG_PATH))) . '=' . BOGUS});
+                        {bStandby => true, iExpectedExitStatus => ERROR_DB_CONNECT, strOptionalParam => '--pg8-host=' . BOGUS});
                 }
                 else
                 {
                     my $strStandbyBackup = $oHostBackup->backup(
                         CFGOPTVAL_BACKUP_TYPE_FULL, 'backup from standby, failure to access at least one standby',
-                        {bStandby => true,
-                         iExpectedExitStatus => ERROR_HOST_CONNECT,
-                         strOptionalParam => '--' .
-                         cfgOptionName(cfgOptionIdFromIndex(CFGOPT_PG_HOST, cfgOptionIndexTotal(CFGOPT_PG_PATH))) . '=' . BOGUS});
+                        {bStandby => true, iExpectedExitStatus => ERROR_DB_CONNECT, strOptionalParam => '--pg8-host=' . BOGUS});
                 }
             }
 
@@ -485,7 +490,7 @@ sub run
                 CFGOPTVAL_BACKUP_TYPE_FULL, 'backup from standby',
                 {bStandby => true,
                  iExpectedExitStatus => $oHostDbStandby->pgVersion() >= PG_VERSION_BACKUP_STANDBY ? undef : ERROR_CONFIG,
-                 strOptionalParam => '--' . cfgOptionName(CFGOPT_REPO_RETENTION_FULL) . '=1'});
+                 strOptionalParam => '--repo1-retention-full=1'});
 
             if ($oHostDbStandby->pgVersion() >= PG_VERSION_BACKUP_STANDBY)
             {
@@ -535,16 +540,23 @@ sub run
 
             $oHostDbMaster->stop();
 
-            $oHostBackup->backup(CFGOPTVAL_BACKUP_TYPE_INCR, 'attempt backup when stopped', {iExpectedExitStatus => ERROR_STOP});
+            $oHostBackup->backup(
+                CFGOPTVAL_BACKUP_TYPE_INCR, 'attempt backup when stopped',
+                {iExpectedExitStatus => $oHostBackup == $oHostDbMaster ? ERROR_STOP : ERROR_DB_CONNECT});
 
             $oHostDbMaster->start();
         }
 
-        # Setup the time target
+        # Setup the time targets
         #---------------------------------------------------------------------------------------------------------------------------
+        # If the tests are running quickly then the time target might end up the same as the end time of the prior full backup. That
+        # means restore auto-select will not pick it as a candidate and restore the last backup instead causing the restore compare
+        # to fail. So, sleep one second.
+        sleep(1);
+
         $oHostDbMaster->sqlExecute("update test set message = '$strTimeMessage'");
         $oHostDbMaster->sqlWalRotate();
-        my $strTimeTarget = $oHostDbMaster->sqlSelectOne("select to_char(current_timestamp, 'YYYY-MM-DD HH24:MI:SS.US TZ')");
+        my $strTimeTarget = $oHostDbMaster->sqlSelectOne("select current_timestamp");
         &log(INFO, "        time target is ${strTimeTarget}");
 
         # Incr backup - fail on archive_mode=always when version >= 9.5
@@ -625,9 +637,7 @@ sub run
 
         # Exercise --delta checksum option
         my $strIncrBackup = $oHostBackup->backup(
-            CFGOPTVAL_BACKUP_TYPE_INCR, 'update during backup',
-            {strOptionalParam =>
-                '--' . cfgOptionName(CFGOPT_STOP_AUTO) . ' --' . cfgOptionName(CFGOPT_BUFFER_SIZE) . '=32768 --delta'});
+            CFGOPTVAL_BACKUP_TYPE_INCR, 'update during backup', {strOptionalParam => '--stop-auto --buffer-size=32768 --delta'});
 
         # Ensure the check command runs properly with a tablespace unless there is a bogus host
         if (!$oHostBackup->bogusHost())
@@ -695,9 +705,7 @@ sub run
         if ($bTestLocal)
         {
             # Expect failure because postmaster.pid exists
-            $oHostDbMaster->restore(
-                'postmaster running', cfgDefOptionDefault(CFGCMD_RESTORE, CFGOPT_SET),
-                {iExpectedExitStatus => ERROR_POSTMASTER_RUNNING});
+            $oHostDbMaster->restore('postmaster running', 'latest', {iExpectedExitStatus => ERROR_POSTMASTER_RUNNING});
         }
 
         $oHostDbMaster->clusterStop();
@@ -705,8 +713,7 @@ sub run
         if ($bTestLocal)
         {
             # Expect failure because db path is not empty
-            $oHostDbMaster->restore(
-                'path not empty', cfgDefOptionDefault(CFGCMD_RESTORE, CFGOPT_SET), {iExpectedExitStatus => ERROR_PATH_NOT_EMPTY});
+            $oHostDbMaster->restore('path not empty', 'latest', {iExpectedExitStatus => ERROR_PATH_NOT_EMPTY});
         }
 
         # Drop and recreate db path
@@ -719,7 +726,7 @@ sub run
 
         # Now the restore should work
         $oHostDbMaster->restore(
-            undef, cfgDefOptionDefault(CFGCMD_RESTORE, CFGOPT_SET),
+            undef, 'latest',
             {strOptionalParam => ($bTestLocal ? ' --db-include=test2 --db-include=test3' : '') . ' --buffer-size=16384'});
 
         # Test that the first database has not been restored since --db-include did not include test1
@@ -767,7 +774,7 @@ sub run
         # Version <= 8.4 always places a PG_VERSION file in the tablespace
         if ($oHostDbMaster->pgVersion() <= PG_VERSION_84)
         {
-            if (!storageDb()->exists("${strTablespacePath}/" . DB_FILE_PGVERSION))
+            if (!storageTest()->exists("${strTablespacePath}/" . DB_FILE_PGVERSION))
             {
                 confess &log(ASSERT, "unable to find '" . DB_FILE_PGVERSION . "' in tablespace path '${strTablespacePath}'");
             }
@@ -776,23 +783,23 @@ sub run
         else
         {
             # Backup info will have the catalog number
-            my $oBackupInfo = new pgBackRest::Common::Ini(
-                storageRepo()->pathGet(STORAGE_REPO_BACKUP . qw{/} . FILE_BACKUP_INFO),
-                {bLoad => false, strContent => ${storageRepo()->get(STORAGE_REPO_BACKUP . qw{/} . FILE_BACKUP_INFO)}});
+            my $oBackupInfo = new pgBackRestDoc::Common::Ini(
+                storageRepo(), $oHostBackup->repoBackupPath(FILE_BACKUP_INFO),
+                {bLoad => false, strContent => ${storageRepo()->get($oHostBackup->repoBackupPath(FILE_BACKUP_INFO))}});
 
             # Construct the special path
             $strTablespacePath .=
                 '/PG_' . $oHostDbMaster->pgVersion() . qw{_} . $oBackupInfo->get(INFO_BACKUP_SECTION_DB, INFO_BACKUP_KEY_CATALOG);
 
             # Check that path exists
-            if (!storageDb()->pathExists($strTablespacePath))
+            if (!storageTest()->pathExists($strTablespacePath))
             {
                 confess &log(ASSERT, "unable to find tablespace path '${strTablespacePath}'");
             }
         }
 
         # Make sure there are some files in the tablespace path (exclude PG_VERSION if <= 8.4 since that was tested above)
-        if (grep(!/^PG\_VERSION$/i, storageDb()->list($strTablespacePath)) == 0)
+        if (grep(!/^PG\_VERSION$/i, storageTest()->list($strTablespacePath)) == 0)
         {
             confess &log(ASSERT, "no files found in tablespace path '${strTablespacePath}'");
         }
@@ -862,7 +869,7 @@ sub run
             # Save recovery file to test so we can use it in the next test
             $strRecoveryFile = $oHostDbMaster->pgVersion() >= PG_VERSION_12 ? 'postgresql.auto.conf' : DB_FILE_RECOVERYCONF;
 
-            storageDb()->copy(
+            storageTest()->copy(
                 $oHostDbMaster->dbBasePath() . qw{/} . $strRecoveryFile, $self->testPath() . qw{/} . $strRecoveryFile);
 
             $oHostDbMaster->clusterStart();
@@ -884,16 +891,15 @@ sub run
             executeTest('rm -rf ' . $oHostDbMaster->tablespacePath(1) . "/*");
 
             # Restore recovery file that was saved in last test
-            storageDb()->move($self->testPath . "/${strRecoveryFile}", $oHostDbMaster->dbBasePath() . "/${strRecoveryFile}");
+            storageTest()->move($self->testPath . "/${strRecoveryFile}", $oHostDbMaster->dbBasePath() . "/${strRecoveryFile}");
 
             # Also touch recovery.signal when required
             if ($oHostDbMaster->pgVersion() >= PG_VERSION_12)
             {
-                storageDb()->put($oHostDbMaster->dbBasePath() . "/" . DB_FILE_RECOVERYSIGNAL);
+                storageTest()->put($oHostDbMaster->dbBasePath() . "/" . DB_FILE_RECOVERYSIGNAL);
             }
 
-            $oHostDbMaster->restore(
-                undef, cfgDefOptionDefault(CFGCMD_RESTORE, CFGOPT_SET), {strType => CFGOPTVAL_RESTORE_TYPE_PRESERVE});
+            $oHostDbMaster->restore(undef, 'latest', {strType => CFGOPTVAL_RESTORE_TYPE_PRESERVE});
 
             $oHostDbMaster->clusterStart();
             $oHostDbMaster->sqlSelectOneTest('select message from test', $strXidMessage);
@@ -901,18 +907,19 @@ sub run
             $oHostDbMaster->sqlExecute("update test set message = '$strTimelineMessage'");
         }
 
-        # Restore (restore type = time, inclusive) - there is no exclusive time test because I can't find a way to find the
-        # exact commit time of a transaction.
+        # Restore (restore type = time, inclusive, automatically select backup) - there is no exclusive time test because I can't
+        # find a way to find the exact commit time of a transaction.
         #---------------------------------------------------------------------------------------------------------------------------
         &log(INFO, '    testing recovery type = ' . CFGOPTVAL_RESTORE_TYPE_TIME);
 
         $oHostDbMaster->clusterStop();
 
         $oHostDbMaster->restore(
-            undef, $strFullBackup,
+            undef, 'latest',
             {bDelta => true, strType => CFGOPTVAL_RESTORE_TYPE_TIME, strTarget => $strTimeTarget,
                 strTargetAction => $oHostDbMaster->pgVersion() >= PG_VERSION_91 ? 'promote' : undef,
-                strTargetTimeline => $oHostDbMaster->pgVersion() >= PG_VERSION_12 ? 'current' : undef});
+                strTargetTimeline => $oHostDbMaster->pgVersion() >= PG_VERSION_12 ? 'current' : undef,
+                strBackupExpected => $strFullBackup});
 
         $oHostDbMaster->clusterStart();
         $oHostDbMaster->sqlSelectOneTest('select message from test', $strTimeMessage);
@@ -944,7 +951,7 @@ sub run
             $oHostDbMaster->clusterStop();
 
             $oHostDbMaster->restore(
-                undef, cfgDefOptionDefault(CFGCMD_RESTORE, CFGOPT_SET),
+                undef, 'latest',
                 {bDelta => true, bForce => true, strType => CFGOPTVAL_RESTORE_TYPE_NAME, strTarget => $strNameTarget,
                     strTargetAction => 'promote',
                     strTargetTimeline => $oHostDbMaster->pgVersion() >= PG_VERSION_12 ? 'current' : undef});
@@ -989,15 +996,13 @@ sub run
             # Incr backup - make sure a --no-online backup fails
             #-----------------------------------------------------------------------------------------------------------------------
             $oHostBackup->backup(
-                CFGOPTVAL_BACKUP_TYPE_INCR, 'fail on --no-' . cfgOptionName(CFGOPT_ONLINE),
-                {iExpectedExitStatus => ERROR_POSTMASTER_RUNNING, strOptionalParam => '--no-' . cfgOptionName(CFGOPT_ONLINE)});
+                CFGOPTVAL_BACKUP_TYPE_INCR, 'fail on --no-online',
+                {iExpectedExitStatus => ERROR_POSTMASTER_RUNNING, strOptionalParam => '--no-online'});
 
             # Incr backup - allow --no-online backup to succeed with --force
             #-----------------------------------------------------------------------------------------------------------------------
             $oHostBackup->backup(
-                CFGOPTVAL_BACKUP_TYPE_INCR,
-                'succeed on --no-' . cfgOptionName(CFGOPT_ONLINE) . ' with --' . cfgOptionName(CFGOPT_FORCE),
-                {strOptionalParam => '--no-' . cfgOptionName(CFGOPT_ONLINE) . ' --' . cfgOptionName(CFGOPT_FORCE)});
+                CFGOPTVAL_BACKUP_TYPE_INCR, 'succeed on --no-online with --force', {strOptionalParam => '--no-online --force'});
         }
 
         # Stanza-delete --force without access to pgbackrest on database host
@@ -1009,8 +1014,8 @@ sub run
             {
                 $oHostDbMaster->stop();
                 $oHostBackup->stop({strStanza => $self->stanza});
-                $oHostBackup->stanzaDelete("delete stanza with --force when pgbackrest on pg host not accessible",
-                    {strOptionalParam => ' --' . cfgOptionName(CFGOPT_FORCE)});
+                $oHostBackup->stanzaDelete(
+                    "delete stanza with --force when pgbackrest on pg host not accessible", {strOptionalParam => ' --force'});
                 $oHostDbMaster->start();
                 $oHostBackup->start();
             }
