@@ -45,7 +45,7 @@ const char *hrnReplaceKey(const char *string);
 const char *hrnDiff(const char *actual, const char *expected);
 
 /***********************************************************************************************************************************
-Getters
+Getters/Setters
 ***********************************************************************************************************************************/
 // Time in MS
 uint64_t testTimeMSec(void);
@@ -117,6 +117,8 @@ Test that an expected error is actually thrown and error when it isn't
         THROW_FMT(                                                                                                                 \
             TestError, "statement '%s' returned but error %s, '%s' was expected", #statement, errorTypeName(&errorTypeExpected),   \
             errorMessageExpected);                                                                                                 \
+                                                                                                                                   \
+    stackTraceTestFileLineSet(0);                                                                                                  \
 }
 
 /***********************************************************************************************************************************
@@ -130,6 +132,8 @@ Test error with a formatted expected message
         THROW_FMT(AssertError, "error message needs more than the %zu characters available", sizeof(TEST_ERROR_FMT_buffer));       \
                                                                                                                                    \
     TEST_ERROR(statement, errorTypeExpected, TEST_ERROR_FMT_buffer);                                                               \
+                                                                                                                                   \
+    stackTraceTestFileLineSet(0);                                                                                                  \
 }
 
 /***********************************************************************************************************************************
@@ -354,6 +358,14 @@ Test title macro
         fflush(stdout);                                                                                                            \
     } while(0)
 
+#define TEST_TITLE_FMT(format, ...)                                                                                                \
+    do                                                                                                                             \
+    {                                                                                                                              \
+        hrnTestLogPrefix(__LINE__, false);                                                                                         \
+        printf(format "\n", __VA_ARGS__);                                                                                          \
+        fflush(stdout);                                                                                                            \
+    } while(0)
+
 /***********************************************************************************************************************************
 Is this a 64-bit system?  If not then it is 32-bit since 16-bit systems are not supported.
 ***********************************************************************************************************************************/
