@@ -157,13 +157,18 @@ testRun(void)
             "  --config-path                    base path of pgBackRest configuration files\n"
             "                                   [default=/etc/pgbackrest]\n"
             "  --delta                          restore or backup using checksums [default=n]\n"
+            "  --io-timeout                     i/O timeout [default=60]\n"
             "  --lock-path                      path where lock files are stored\n"
             "                                   [default=/tmp/pgbackrest]\n"
             "  --neutral-umask                  use a neutral umask [default=y]\n"
             "  --process-max                    max processes to use for compress/transfer\n"
             "                                   [default=1]\n"
             "  --protocol-timeout               protocol timeout [default=1830]\n"
+            "  --sck-keep-alive                 keep-alive enable [default=y]\n"
             "  --stanza                         defines the stanza\n"
+            "  --tcp-keep-alive-count           keep-alive count\n"
+            "  --tcp-keep-alive-idle            keep-alive idle time\n"
+            "  --tcp-keep-alive-interval        keep-alive interval time\n"
             "\n"
             "Log Options:\n"
             "\n"
