@@ -84,13 +84,14 @@ test.pl [options]
    --coverage-only      only run coverage tests (as a subset of selected tests)
    --c-only             only run C tests
    --container-only     only run tests that must be run in a container
+   --no-performance     do not run performance tests
    --gen-only           only run auto-generation
    --no-gen             do not run code generation
    --code-count         generate code counts
    --smart              perform bin/package builds only when source timestamps have changed
    --dev                --smart --no-optimize
    --dev-test           does nothing -- kept for backward compatibility
-   --expect             --vm=co7 --db=9.6 --log-force
+   --expect             --vm=co7 --pg-version=9.6 --log-force
    --no-valgrind        don't run valgrind on C unit tests (saves time)
    --no-coverage        don't run coverage on C unit tests (saves time)
    --no-optimize        don't do compile optimization for C (saves compile time)
@@ -161,6 +162,7 @@ my $bCoverageSummary = false;
 my $bNoCoverage = false;
 my $bCOnly = false;
 my $bContainerOnly = false;
+my $bNoPerformance = false;
 my $bGenOnly = false;
 my $bNoGen = false;
 my $bCodeCount = false;
@@ -213,6 +215,7 @@ GetOptions ('q|quiet' => \$bQuiet,
             'no-coverage' => \$bNoCoverage,
             'c-only' => \$bCOnly,
             'container-only' => \$bContainerOnly,
+            'no-performance' => \$bNoPerformance,
             'gen-only' => \$bGenOnly,
             'no-gen' => \$bNoGen,
             'code-count' => \$bCodeCount,
@@ -702,7 +705,8 @@ eval
         {
             # Get the test list
             $oyTestRun = testListGet(
-                $strVm, \@stryModule, \@stryModuleTest, \@iyModuleTestRun, $strPgVersion, $bCoverageOnly, $bCOnly, $bContainerOnly);
+                $strVm, \@stryModule, \@stryModuleTest, \@iyModuleTestRun, $strPgVersion, $bCoverageOnly, $bCOnly, $bContainerOnly,
+                $bNoPerformance);
 
             # Determine if the C binary and test library need to be built
             foreach my $hTest (@{$oyTestRun})
@@ -956,11 +960,11 @@ eval
                             "bash -c \"" .
                             "mkdir /root/package-src && " .
                             "wget -q -O /root/package-src/pgbackrest-conf.patch " .
-                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;" .
-                                "f=rpm/redhat/master/pgbackrest/master/pgbackrest-conf.patch;hb=refs/heads/master' && " .
+                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/master;" .
+                                "f=rpm/redhat/master/non-common/pgbackrest/master/pgbackrest-conf.patch' && " .
                             "wget -q -O /root/package-src/pgbackrest.spec " .
-                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;" .
-                                "f=rpm/redhat/master/pgbackrest/master/pgbackrest.spec;hb=refs/heads/master'\"");
+                                "'https://git.postgresql.org/gitweb/?p=pgrpms.git;a=blob_plain;hb=refs/heads/master;" .
+                                "f=rpm/redhat/master/non-common/pgbackrest/master/pgbackrest.spec'\"");
 
                         # Create build directories
                         $oStorageBackRest->pathCreate($strBuildPath, {bIgnoreExists => true, bCreateParent => true});
